(* ::Package:: *)


$HistoryLength=0;

(*Cosmological  Parameters *)
(* CMB Temperature in K *)
TCMB=2.725;
(* Baryon density *)
\[CapitalOmega]b=.0458;
(* Cold Dark matter density *)
\[CapitalOmega]cdm=.229;
(* Hubble parameter *)
h0=0.702;
(*Helium mass fraction *)
fmHe=0.24;
(* Minimum redshift *)
zmin=200.0;
(* Distortions are calculated below by assuming that all the injected energy goes to radiation (except for baryonic cooling for which electron temperature is evolved).
At z=500 electron temperature differs from radiation temperature by 1% and at z=200 the difference is 10%. 
Below z<200 we cannot asssume that all energy added to the plasma goes to radiation and electron temperature must be evolved
to accurately calculate the y-distortion. See the function dQdzcool[z] below. z<200 is therefore not recommended. *)

(* Maximum redshift *)
zmax=5.0*10^6;
(* Number of neutrinos *)
Nnu=3.046;
(* File with electron fraction with respect to hydrogen (z,ne/nH) as a function of redshift, 
Can be calculated from public codes Recfast,HyRec,CosmoRec with highest redshift  at least before start of helium recombination, z=10000 
and lowest redshift at least 100 *)
xefile="xe.dat";
(* Root for template files *)
(*root="intermdediate_templates/";*)
root="intermediate_distortion_templates/";
(*Output file for x,delta n/n*)
outfile1="nxout.dat";

(*output file for \[Nu] (GHz), Subscript[I, \[Nu]](W m^-2Sr^-1Hz^-1)*)
outfile2="Inuout.dat";

(*files for error plot output*)
(* Error in total spectrum because of ymin/ymax boundaries for y/mu type distortions *)
error1file="error1.eps";
(* error with respect to numerical results in examples directory *)
error2file="error2.eps";

(*Maxmium and minimum Subscript[y, \[Gamma]] for intermediate type distortions. Above ymax the distortion is assumed to be pure \[Mu] and below ymin distortion is pure y*)
ymax=2.0;
ymin=0.01;

(* Check accuracy of final spectrum if checkAccuracy=1 by making ymin=0.001, ymax=10 *)
checkAccuracy=1;

(*Reuse cosmological data: fresh calculation if 0,  otherwise, y parameter and damping scales  are reused from previous runs, saves lot of time*)
reuse=1;
ytozfile="ytoz_reuse.dat";
ztotfile="ztot_reuse.dat";
dampfile="kD_reuse.dat";
tefile="te_reuse.dat";

(*Whether use approximate weights or do the integral to calculate energy release*)
precision=0;
(* Calculate for Silk Damping mode=0, dark matter decay  mode=1, custom energy injection  mode=2 *)
(*If mode is not equal to any of these values, only adiabatic cooling is calculates *)

mode=-1;

(*Silk damping parameters for power spectrum *)
(*Spectral index on small scales*)
ns=1.5;
(* Amplitude *)
A\[Zeta]=1.61*10^-9;
(* pivot point in Mpc*)
k0Mpc=42.0;

(* Dark matter decay parameters *)

(* specify either decay redshift (zORt=0) or lifetime \[Tau]decay (zORt=1), Subscript[n, dm](t)=Subscript[n, dm](initial)*\[ExponentialE]^(-t/\[Tau]decay), zdecay is defined by , \[Tau]decay=Subscript[\[Integral], \[Infinity]]^zdecaydt, t is proper time. *)
zORt=0;
(*decay redshift*)
zdecay=7.0*10^4;
(*decay time *)
(*\[Tau]decay=time[zdecay];*)
(*amplitude of distortion= (Subscript[f, \[Gamma]]Subscript[n, X0]Subscript[m, X]c^2)/(Subscript[a, R]TCMB^4(1+zdecay))*)
amplitude=10^-7;

(* Custom energy release dQ/dz *)
(* Dark matter annihilation example *)
\[Sigma]v=(3*10^-27)/(\[CapitalOmega]cdm h0^2);
mdm=10 GeV/c^2;
ndm[z_]=\[Rho]cr*\[CapitalOmega]cdm/mdm (1+z)^3;
f\[Gamma]=1;
dQdzCustom[z_]= f\[Gamma] (mdm c^2 ndm[z]^2 \[Sigma]v)/(a TCMB^4 (1+z)^5 H[z]);

(*Physical constants *)
(* Compton scattering crossections *)
\[Sigma]T=6.65246*10^(-25);
\[Sigma][x_]:=\[Sigma]T*3/4 ((1.+x)/x^3 ((2 x (1+x))/(1+2 x)-Log[1+2 x])+1/(2 x) Log[1+2 x]-(1+3 x)/(1+2 x)^2);
G=6.6742*10^(-8);(*cgs*)
a=7.5658*10^(-15);(*radiation constant cgs*)
c=2.99792458*10^(10);(*cm/s*)
parsec=3.0856776*10^(18);(*cm*)
mparsec=parsec*10^6;
\[Alpha]fs=1/137.036;(* Fine structure constant *)
kb=1.3806505*10^(-16);(*Boltzmann cgs*)
hb=1.05457168*10^(-27);(*Planck/2\[Pi] cgs*)
h=2*\[Pi]*hb;
me=9.1093826*10^(-28);(*mass of electron g*)
ev=1.60217646*10^-12;
GeV=ev*10^9;
(*Helium fraction Y=0.24*)
(* Total Matter density *)

\[CapitalOmega]m=\[CapitalOmega]cdm+\[CapitalOmega]b;
H0=h0*100*3.24077649*10^(-20) ;(*s^-1*) 
fHe=fmHe/(3.9715*0.76);
fnu=Nnu*7.0/8 (4/11)^(4/3);
zeq=(3 (H0 *c)^2 * \[CapitalOmega]m)/(8 \[Pi] G a TCMB^4 (1+fnu))-1;
\[CapitalOmega]r=\[CapitalOmega]m/(1+zeq);

H[x_]:=H0*Sqrt[(1+x)^4 * \[CapitalOmega]r+\[CapitalOmega]m *(1+x)^3+(1-(\[CapitalOmega]m+\[CapitalOmega]r))];
\[Rho]cr=1/(8 \[Pi]/3*G/H[0]^2);
time[z_]:=NIntegrate[1/((1+x)*H[x]),{x,z,Max[10^4*z,10^5]},Method->{"GlobalAdaptive",Method->{"TrapezoidalRule","RombergQuadrature"->True}}];
nH[z_]:=(1+z)^3*\[CapitalOmega]b*.76*\[Rho]cr/(1.67262*10^(-24)+9.1*10^(-28));
nHe[z_]:=nH[z]*fHe;

xedata=ReadList[xefile,{Real,Real}];
xein=Interpolation[xedata,InterpolationOrder->2];
xezmax=Max[First[First[xedata]],First[Last[xedata]]];
xhighz=xein[xezmax];
xezmin=Min[First[First[xedata]],First[Last[xedata]]];
If[xezmin>101,Print["Warning: Minimum redshift in recombination history must be <=100"];Print["Input file has minimum redshift z=",xezmin]; Exit[];];
xe[z_]=If[z<xezmax,xein[z],xhighz];
ne[z_]=xe[z]*nH[z];
bigA=kb*\[Sigma]T/(me*c);
yy[z_]:=NIntegrate[bigA*ne[x]*TCMB*(1+x)*1/(H[x]*(1+x)),{x,xezmin,z},Method->{"GlobalAdaptive",Method->{"GaussKronrodRule"},"SingularityDepth"->\[Infinity]},PrecisionGoal->6,MaxRecursion->15];


izmax=1000;
dz=1.0*Log[zmax/zmin]/izmax;
If[reuse==0,
For[i=1,i<=izmax+1,i++,
    zsamp[i]=Exp[Log[zmin]+(i-1)*dz];
    ysamp[i]=Log[yy[zsamp[i]]];
    tsamp[i]=Log[time[zsamp[i]]];
    ];
ytozdata=Table[Flatten[{ysamp[i],Log[zsamp[i]]}],{i,1,izmax+1}];
ztotdata=Table[Flatten[{Log[zsamp[i]],tsamp[i]}],{i,1,izmax+1}];
Export[ytozfile,ytozdata];
Export[ztotfile,ztotdata];,
ytozdata=ReadList[ytozfile,{Real,Real}];
ztotdata=ReadList[ztotfile,{Real,Real}];
];
zdata=Part[Transpose[ztotdata],1];
tdata=Part[Transpose[ztotdata],2];
ttozdata=Transpose[{tdata,zdata}];

ytozint=Interpolation[ytozdata];
ztotint=Interpolation[ztotdata];
ttozint=Interpolation[ttozdata];

ytoz[y_]=Exp[ytozint[Log[y]]];
ztot[z_]=Exp[ztotint[Log[z]]];
ttoz[z_]=Exp[ttozint[Log[z]]];

Print["Solving ODE for Electron temperature"];
coolcomp[z_]:=8 \[Sigma]T a (TCMB (1+z))^4 xe[z]/(3*me c*(1.0+fHe+xe[z]));

If[reuse==0,
solrho=NDSolve[{D[\[Rho][z],z]==-1/(H[z]*(1+z)) (coolcomp[z]*(1.0-\[Rho][z]))+\[Rho][z]/(1+z),\[Rho][zmax*1.1]==1.0},\[Rho],{z,zmin,zmax*1.1},Method->{"BDF","MaxDifferenceOrder"->2,"VariableStepCoefficients"->True},AccuracyGoal->15,MaxStepFraction->10^-5,MaxSteps->10^7,InterpolationOrder->All];
Tetbl=Table[Flatten[{Log[zsamp[i]],Log[1.0-\[Rho][zsamp[i]]/.solrho]}],{i,1,izmax+1}];
Export[tefile,Tetbl];,
Tetbl=ReadList[tefile,{Real,Real}];];

teint=Interpolation[Tetbl];
tgminuste[z_]=Exp[teint[Log[z]]];


(*Calculate Blackbody Optical depth, see  arXiv:1203.2601 for details*)
dcompton[z_]:=1.005*ne[z]*\[Sigma]T c  4*\[Alpha]fs/(3*\[Pi])*(kb *TCMB*(1+z)/(me*c^2))^2*25.976;

kcomp[z_]=c ne[z] \[Sigma]T kb TCMB (1+z)/(me c^2);

brehm[z_]:= 2.99*ne[z]*\[Sigma]T c ( \[Alpha]fs*(nH[z]+4*nHe[z]))/(24 \[Pi]^3)^(1/2)*((me *c^2)/( kb *TCMB *(1+z)))^(7/2) *(h/(me c))^3;
ztau=1.96*10^6;
abr=brehm[ztau]/(1+ztau)^(5/2);
adC=dcompton[ztau]/(1+ztau)^5;
aC=kcomp[ztau]/(1+ztau)^4;
kC=0.7768;
aH=(\[CapitalOmega]r H0^2);

zbr=((25 aH)/(4 kC^2 aC*abr))^(2/5);

zdC=((25 aH)/(4 kC^2 aC*adC))^(1/5);
z\[Epsilon]=(abr/adC)^(2/5);

\[Epsilon]=(kC 2 abr )/(5 Sqrt[(adC aH)/aC]);
zbr22= (aH^(1/2)/(2 abr kC *2.958 ))^2;
zdc22= ((3 aH^(1/2))/( adC kC *2.958 ))^(1/3);
tau1[z_]=(((1+z)/(1+zdC))^5+((1+z)/(1+zbr))^(5/2))^(1/2)+\[Epsilon] Log[((1+z)/(1+z\[Epsilon]))^(5/4)+(1+((1+z)/(1+z\[Epsilon]))^(5/2))^(1/2)];
tau2[z_]=((1+z)/(1+zbr22))^(1/2)+((1+z)/(1+zdc22))^3;

tau[z_]=1.007 tau1[z]+tau2[z];


xmin=10^(-5);
xmax=120.0;
zzmin=Log[xmin];
zzmax=Log[xmax];
nbb[x_]=1.0/(Exp[x]-1.0);

nszsol[x_]=(x Exp[x])/(Exp[x]-1) (x (Exp[x]+1)/(Exp[x]-1)-4);
musol[x_]=(Exp[x])/(Exp[x]-1)(x/2.19-1);
dydz[z_]=kb \[Sigma]T ne[z]TCMB (1+z)/(me c H[z] (1+z));

If[mode==0,
(*Silk Damping setup*)
R[z_] := 3/4 *\[CapitalOmega]b/(\[CapitalOmega]r*(1 + z));
dkddzdamp[z_] := (c*(1 + z))/(6*H[z]*(1 + R[z]) ne[z]*\[Sigma]T) (R[z]^2/(1 + R[z]) + 16/15);
okd2[z_] := NIntegrate[dkddzdamp[zz], {zz, z, \[Infinity]}, Method -> {"GlobalAdaptive", Method -> {"GaussKronrodRule"}, "SingularityDepth" -> \[Infinity]}, PrecisionGoal -> 6, MaxRecursion -> 30];
If[reuse==0,
kdtbl = Table[Flatten[{z, Log[(1/okd2[Exp[z]])^(1/2)]}], {z, Log[1000.0], Log[zmax], Log[zmax/1000]/500.0}];
Export[dampfile,kdtbl];,
kdtbl=ReadList[dampfile,{Real,Real}];
];
kdint = Interpolation[kdtbl];
kd[z_] := Exp[kdint[Log[z]]];
k0=k0Mpc/mparsec;
dQdz[z_]=3/4*4.3 A\[Zeta]/k0^(ns-1)dkddzdamp[z] 2^(-(3+ns)/2) kd[z]^(ns+1) Gamma[(ns+1)/2];,
If[mode==1,
(* Particle decay setup*)
If[zORt==0,
\[Tau]decay=time[zdecay];,
zdecay=ttoz[\[Tau]decay];
];
dQdz[z_]=10^(-7)*(1+zdecay)Exp[-ztot[z]/\[Tau]decay]/(H[z]*(1+z)^2*\[Tau]decay);,
If[mode==2,
(*Custom energy release *)
dQdz[z_]=dQdzCustom[z];,
dQdz[z_]=0;
];
];
];
(* Take into account adiabatic cooling of baryons *)
dQdzcooly[z_]= 4 kb \[Sigma]T  (TCMB (1+z)) ne[z]*tgminuste[z]/(me c*H[z](1+z));
dQdzcool[z_]=3/2 kb TCMB (1+z)*(2*nH[z]+3*nHe[z])/(a (TCMB*(1+z))^4)/(1+z);

ystr="nkomp_ad_y5_itr_1_1901_";

y1=0.0;
k=0;
yout[k]=y1;
y2=0.0;
maxflag=1;
minflag=1;
While[y2<=10.0,
      If[y1>1.0,\[Delta]y=0.01,\[Delta]y=0.001];
y2=y1+\[Delta]y;
k=k+1;
yout[k]=y2;
y1=y2;
If[y2>=ymax && maxflag==1,imaxout=k;maxflag=0;];
If[y2>=ymin && minflag==1,iminout=k;minflag=0;];
];
imax=k;
Print["Total Files=",imax];
(*ymin=0.01*)
Print["ymin=",yout[iminout]];
(*ymax=2*)
Print["ymax=",yout[imaxout]];
For[i=iminout,i<=imaxout,i++,
(*Print["i=",i];*)
y2=yout[i];
If[i==imaxout,yip1=y2;,yip1=yout[i+1];];
If[i==iminout,yim1=y2;,yim1=yout[i-1];];
dy=(yip1-yim1)/2.0;
(*Calculate weights =energy/4*10^5*)
If[precision==0,
yamplitude[i]=10^5*0.25*(dQdz[ytoz[y2]]-dQdzcool[ytoz[y2]])/dydz[ytoz[y2]]*dy;,
yamplitude[i]= 10^5*0.25*NIntegrate[(dQdz[z]-dQdzcool[z]),{z,ytoz[(y2+yim1)/2.0],ytoz[(yip1+y2)/2.0]},Method->{"GlobalAdaptive",Method->{"GaussKronrodRule"},"SingularityDepth"->\[Infinity]},PrecisionGoal->9,MaxRecursion->20];
];
file=OpenRead[root<>ystr<>ToString[y2]<>".dat"];
data=ReadList[file,{Real,Real}];
If[i==imaxout, xdata=Part[Transpose[data],1];];
nxdata=Part[Transpose[data],2];
If[i==iminout,nx=yamplitude[i]*nxdata;,
nx=nx+yamplitude[i]*nxdata;
];
Close[file];
];
nxfinal=nx;
freq=1/(h /(kb TCMB));
inten=10^-3*2 h freq^3/c^2;
z1=ytoz[yout[iminout]];
z2=ytoz[yout[imaxout]];
(*For silk damping y-distortion is only an order of magnitude estimate, cutoff at recombination*)
If[mode==0,zminint=1000.0,zminint=zmin];
youtamp= 0.25*NIntegrate[(dQdz[z]-dQdzcooly[z]),{z,zminint,z1},Method->{"GlobalAdaptive",Method->{"GaussKronrodRule"},"SingularityDepth"->\[Infinity]},PrecisionGoal->9,MaxRecursion->20];
muoutamp= 1.4*NIntegrate[Exp[-tau[z]]*(dQdz[z]-dQdzcool[z]),{z,z2,zmax},Method->{"GlobalAdaptive",Method->{"GaussKronrodRule"},"SingularityDepth"->\[Infinity]},PrecisionGoal->9,MaxRecursion->20];
youtdata=Table[youtamp*nszsol[Exp[z]],{z,zzmin,zzmax,(zzmax-zzmin)/1000.0}];
muoutdata=Table[muoutamp*musol[Exp[z]],{z,zzmin,zzmax,(zzmax-zzmin)/1000.0}];
(* 150:975 elements of the array select approximately x>10^-4, x<80 to avoid boundaries of the solution in the templates*)
nxoutdata=Transpose[{Part[Exp[xdata],150;;975],Part[nx,150;;975],Part[youtdata,150;;975],Part[muoutdata,150;;975],Part[nx+youtdata+muoutdata,150;;975]}];
Inuoutdata=Transpose[{Part[Exp[xdata]*freq/10^9,150;;975],Part[inten*Exp[xdata]^3*nx*nbb[Exp[xdata]],150;;975],Part[inten*Exp[xdata]^3*youtdata*nbb[Exp[xdata]],150;;975],Part[inten*Exp[xdata]^3*muoutdata*nbb[Exp[xdata]],150;;975],Part[inten*Exp[xdata]^3*(nx+youtdata+muoutdata)*nbb[Exp[xdata]],150;;975]}];
Export[outfile1,nxoutdata];
Export[outfile2,Inuoutdata];
Print["\[Mu]-type distortion: \[Mu]=",muoutamp];
Print["y-type distortion: y=",youtamp];
youtdatafinal=youtdata;
muoutdatafinal=muoutdata;



If[checkAccuracy==1,
nx=nxfinal;
(*Read Rest of the files *)
For[i=1,i<=iminout-1,i++,
(*Print["i=",i];*)
y2=yout[i];
If[i==iminout-1,yip1=y2;,yip1=yout[i+1];];
If[i==1,yim1=y2;,yim1=yout[i-1];];
dy=(yip1-yim1)/2.0;
(*Calculate weights =energy/4*10^5*)
If[precision==1,
yamplitude[i]=10^5*0.25*(dQdz[ytoz[y2]]-dQdzcool[ytoz[y2]])/dydz[ytoz[y2]]*dy;,
yamplitude[i]= 10^5*0.25*NIntegrate[(dQdz[z]-dQdzcool[z]),{z,ytoz[(y2+yim1)/2.0],ytoz[(yip1+y2)/2.0]},Method->{"GlobalAdaptive",Method->{"GaussKronrodRule"},"SingularityDepth"->\[Infinity]},PrecisionGoal->9,MaxRecursion->20];
];
file=OpenRead[root<>ystr<>ToString[y2]<>".dat"];
data=ReadList[file,{Real,Real}];
nxdata=Part[Transpose[data],2];
nx=nx+yamplitude[i]*nxdata;
Close[file];
];
For[i=imaxout+1,i<=imax,i++,
(*Print["i=",i];*)
y2=yout[i];
If[i==imax,yip1=y2;,yip1=yout[i+1];];
If[i==imaxout+1,yim1=y2;,yim1=yout[i-1];];
dy=(yip1-yim1)/2.0;
(*Calculate weights =energy/4*10^5*)
If[precision==1,
yamplitude[i]=10^5*0.25*(dQdz[ytoz[y2]]-dQdzcool[ytoz[y2]])/dydz[ytoz[y2]]*dy;,
yamplitude[i]= 10^5*0.25*NIntegrate[(dQdz[z]-dQdzcool[z]),{z,ytoz[(y2+yim1)/2.0],ytoz[(yip1+y2)/2.0]},Method->{"GlobalAdaptive",Method->{"GaussKronrodRule"},"SingularityDepth"->\[Infinity]},PrecisionGoal->9,MaxRecursion->20];
];
file=OpenRead[root<>ystr<>ToString[y2]<>".dat"];
data=ReadList[file,{Real,Real}];
nxdata=Part[Transpose[data],2];
nx=nx+yamplitude[i]*nxdata;
Close[file];
];
nxfinalac=nx;
z1ac=ytoz[yout[1]];
z2ac=ytoz[yout[imax]];
youtamp= 0.25*NIntegrate[(dQdz[z]-dQdzcooly[z]),{z,zminint,z1ac},Method->{"GlobalAdaptive",Method->{"GaussKronrodRule"},"SingularityDepth"->\[Infinity]},PrecisionGoal->9,MaxRecursion->20];
muoutamp= 1.4*NIntegrate[Exp[-tau[z]]*(dQdz[z]-dQdzcool[z]),{z,z2ac,zmax},Method->{"GlobalAdaptive",Method->{"GaussKronrodRule"},"SingularityDepth"->\[Infinity]},PrecisionGoal->9,MaxRecursion->20];
youtdata=Table[youtamp*nszsol[Exp[z]],{z,zzmin,zzmax,(zzmax-zzmin)/1000.0}];
muoutdata=Table[muoutamp*musol[Exp[z]],{z,zzmin,zzmax,(zzmax-zzmin)/1000.0}];
(*Discard boundary part of the spectrum *)
nxoutdata=Transpose[{Part[Exp[xdata],150;;975],Part[nx,150;;975],Part[youtdata,150;;975],Part[muoutdata,150;;975],Part[nx+youtdata+muoutdata,150;;975]}];
Inuoutdata=Transpose[{Part[Exp[xdata]*freq/10^9,150;;975],Part[inten*Exp[xdata]^3*nx*nbb[Exp[xdata]],150;;975],Part[inten*Exp[xdata]^3*youtdata*nbb[Exp[xdata]],150;;975],Part[inten*Exp[xdata]^3*muoutdata*nbb[Exp[xdata]],150;;975],Part[inten*Exp[xdata]^3*(nx+youtdata+muoutdata)*nbb[Exp[xdata]],150;;975]}];
outfile1ac="ac_check"<>outfile1;
outfile2ac="ac_check"<>outfile2;

Export[outfile1ac,nxoutdata];
Export[outfile2ac,Inuoutdata];
Print["Accuracy Check: \[Mu]-type distortion: \[Mu]=",muoutamp];
Print["Accuracy Check: y-type distortion: y=",youtamp];
youtdatafinalac=youtdata;
muoutdatafinalac=muoutdata;
(*Checks *)

intensityint=Interpolation[Transpose[{xdata,(nxfinal+youtdatafinal+muoutdatafinal)}]];
intensity[x_]:=intensityint[Log[x]];
Accurateintensityint=Interpolation[Transpose[{xdata,(nxfinalac+youtdatafinalac+muoutdatafinalac)}]];
Accurateintensity[x_]=Accurateintensityint[Log[x]]; 
(*To prevent the error from blowing up when denominator goes to zero*)
Totaly=0.125*NIntegrate[(dQdz[z]-dQdzcooly[z]),{z,z1,z2},Method->{"GlobalAdaptive",Method->{"GaussKronrodRule"},"SingularityDepth"->\[Infinity]},PrecisionGoal->9,MaxRecursion->20];

intensityError[x_]:=(intensity[x]-Accurateintensity[x])/Max[Abs[Accurateintensity[x]],Abs[Totaly],Abs[youtamp]/2,Abs[muoutamp]/10];
plot1=LogLinearPlot[intensityError[x],{x,0.2,10},AxesLabel->{"x","fractional Error"},PlotLabel->"Error due to assuming ymin,ymax=0.001,2",PlotRange->All];
Export[error1file,plot1];
];



(* ::Input:: *)
(*(*Check with numerical solutions given in examples *)*)
(*spectrumfile="examples/Particle_decay_z7.0e4.dat";*)
(*spectrumdata=Interpolation[ReadList[spectrumfile,{Real,Real}]];*)
(*ispectrum[x_]=spectrumdata[Log[x]];*)
(*internxint=Interpolation[Transpose[{xdata,nxfinal}]];*)
(*internx[x_]:=internxint[Log[x]];*)
(*internxError[x_]:=(internx[x]-ispectrum[x])/Max[Abs[ispectrum[x]],Abs[Totaly],Abs[youtamp]/2,Abs[muoutamp]/10];*)
(*plot2=LogLinearPlot[internxError[x],{x,0.1,10},AxesLabel->{"x","fractional Error"},PlotLabel->"Error with respect to numerical solution"];*)
(*Export[error2file,plot2];*)
(**)
(**)
(**)
