(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     97288,       2616]
NotebookOptionsPosition[     96529,       2588]
NotebookOutlinePosition[     96963,       2605]
CellTagsIndexPosition[     96920,       2602]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 RowBox[{"\n", 
  RowBox[{
   RowBox[{
    RowBox[{"$HistoryLength", "=", "0"}], ";"}], "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{"Cosmological", "  ", "Parameters"}], " ", "*)"}], "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"CMB", " ", "Temperature", " ", "in", " ", "K"}], " ", "*)"}], 
   "\n", 
   RowBox[{
    RowBox[{"TCMB", "=", "2.725"}], ";"}], "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"Baryon", " ", "density"}], " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{"\[CapitalOmega]b", "=", ".0458"}], ";"}], "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"Cold", " ", "Dark", " ", "matter", " ", "density"}], " ", "*)"}],
    "\n", 
   RowBox[{
    RowBox[{"\[CapitalOmega]cdm", "=", ".229"}], ";"}], "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"Hubble", " ", "parameter"}], " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{"h0", "=", "0.702"}], ";"}], "\n", 
   RowBox[{"(*", 
    RowBox[{"Helium", " ", "mass", " ", "fraction"}], " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{"fmHe", "=", "0.24"}], ";"}], "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"Minimum", " ", "redshift"}], " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{"zmin", "=", "200.0"}], ";"}], "\n", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "Distortions", " ", "are", " ", "calculated", " ", "below", " ", "by", 
      " ", "assuming", " ", "that", " ", "all", " ", "the", " ", "injected", 
      " ", "energy", " ", "goes", " ", "to", " ", "radiation", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
        "except", " ", "for", " ", "baryonic", " ", "cooling", " ", "for", 
         " ", "which", " ", "electron", " ", "temperature", " ", "is", " ", 
         "evolved"}], ")"}], ".", "\n", "At"}], " ", "z"}], "=", 
     RowBox[{
      RowBox[{
      "500", " ", "electron", " ", "temperature", " ", "differs", " ", "from",
        " ", "radiation", " ", "temperature", " ", "by", " ", "1", "%", " ", 
       "and", " ", "at", " ", "z"}], "=", 
      RowBox[{
       RowBox[{"200", " ", "the", " ", "difference", " ", "is", " ", "10", 
        RowBox[{"%", ".", " ", "\n", "Below"}], " ", "z"}], "<", 
       RowBox[{
        RowBox[{
        "200", " ", "we", " ", "cannot", " ", "asssume", " ", "that", " ", 
         "all", " ", "energy", " ", "added", " ", "to", " ", "the", " ", 
         "plasma", " ", "goes", " ", "to", " ", "radiation", " ", "and", " ", 
         "electron", " ", "temperature", " ", "must", " ", "be", " ", 
         "evolved", "\n", "to", " ", "accurately", " ", "calculate", " ", 
         "the", " ", "y"}], "-", 
        RowBox[{
         RowBox[{"distortion", ".", " ", "See"}], " ", "the", " ", "function",
          " ", 
         RowBox[{"dQdzcool", "[", "z", "]"}], " ", 
         RowBox[{"below", ".", " ", "z"}]}]}], "<", 
       RowBox[{"200", " ", "is", " ", "therefore", " ", "not", " ", 
        RowBox[{"recommended", "."}]}]}]}]}], " ", "*)"}], "\n", "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"Maximum", " ", "redshift"}], " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{"zmax", "=", 
     RowBox[{"5.0", "*", 
      RowBox[{"10", "^", "6"}]}]}], ";"}], "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"Number", " ", "of", " ", "neutrinos"}], " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{"Nnu", "=", "3.046"}], ";"}], "\n", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
     "File", " ", "with", " ", "electron", " ", "fraction", " ", "with", " ", 
      "respect", " ", "to", " ", "hydrogen", " ", 
      RowBox[{"(", 
       RowBox[{"z", ",", 
        RowBox[{"ne", "/", "nH"}]}], ")"}], " ", "as", " ", "a", " ", 
      "function", " ", "of", " ", "redshift"}], ",", " ", "\n", 
     RowBox[{
     "Can", " ", "be", " ", "calculated", " ", "from", " ", "public", " ", 
      "codes", " ", "Recfast"}], ",", "HyRec", ",", 
     RowBox[{
     "CosmoRec", " ", "with", " ", "highest", " ", "redshift", "  ", "at", 
      " ", "least", " ", "before", " ", "start", " ", "of", " ", "helium", 
      " ", "recombination"}], ",", " ", 
     RowBox[{"z", "=", 
      RowBox[{
      "10000", " ", "\n", "and", " ", "lowest", " ", "redshift", " ", "at", 
       " ", "least", " ", "100"}]}]}], " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{"xefile", "=", "\"\<xe.dat\>\""}], ";"}], "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"Root", " ", "for", " ", "template", " ", "files"}], " ", "*)"}], 
   "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"root", "=", "\"\<intermdediate_templates/\>\""}], ";"}], "*)"}],
    "\n", 
   RowBox[{
    RowBox[{"root", "=", "\"\<intermediate_distortion_templates/\>\""}], 
    ";"}], "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Output", " ", "file", " ", "for", " ", "x"}], ",", 
     RowBox[{"delta", " ", 
      RowBox[{"n", "/", "n"}]}]}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"outfile1", "=", "\"\<nxout.dat\>\""}], ";"}], "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"output", " ", "file", " ", "for", " ", "\[Nu]", " ", 
      RowBox[{"(", "GHz", ")"}]}], ",", " ", 
     RowBox[{
      SubscriptBox["I", "\[Nu]"], 
      RowBox[{"(", 
       RowBox[{"W", " ", 
        SuperscriptBox["m", 
         RowBox[{"-", "2"}]], 
        SuperscriptBox["Sr", 
         RowBox[{"-", "1"}]], 
        SuperscriptBox["Hz", 
         RowBox[{"-", "1"}]]}], ")"}]}]}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"outfile2", "=", "\"\<Inuout.dat\>\""}], ";"}], "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{"files", " ", "for", " ", "error", " ", "plot", " ", "output"}], 
    "*)"}], "\n", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Error", " ", "in", " ", "total", " ", "spectrum", " ", "because", " ", 
     "of", " ", 
     RowBox[{"ymin", "/", "ymax"}], " ", "boundaries", " ", "for", " ", 
     RowBox[{"y", "/", "mu"}], " ", "type", " ", "distortions"}], " ", "*)"}],
    "\n", 
   RowBox[{
    RowBox[{"error1file", "=", "\"\<error1.eps\>\""}], ";"}], "\n", 
   RowBox[{"(*", " ", 
    RowBox[{
    "error", " ", "with", " ", "respect", " ", "to", " ", "numerical", " ", 
     "results", " ", "in", " ", "examples", " ", "directory"}], " ", "*)"}], 
   "\n", 
   RowBox[{
    RowBox[{"error2file", "=", "\"\<error2.eps\>\""}], ";"}], "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{"Maxmium", " ", "and", " ", "minimum", " ", 
     SubscriptBox["y", "\[Gamma]"], " ", "for", " ", "intermediate", " ", 
     "type", " ", 
     RowBox[{"distortions", ".", " ", "Above"}], " ", "ymax", " ", "the", " ",
      "distortion", " ", "is", " ", "assumed", " ", "to", " ", "be", " ", 
     "pure", " ", "\[Mu]", " ", "and", " ", "below", " ", "ymin", " ", 
     "distortion", " ", "is", " ", "pure", " ", "y"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"ymax", "=", "2.0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"ymin", "=", "0.01"}], ";"}], "\n", "\n", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
      "Check", " ", "accuracy", " ", "of", " ", "final", " ", "spectrum", " ",
        "if", " ", "checkAccuracy"}], "=", 
      RowBox[{
       RowBox[{"1", " ", "by", " ", "making", " ", "ymin"}], "=", "0.001"}]}],
      ",", " ", 
     RowBox[{"ymax", "=", "10"}]}], " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{"checkAccuracy", "=", "1"}], ";"}], "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Reuse", " ", "cosmological", " ", 
      RowBox[{"data", ":", " ", 
       RowBox[{"fresh", " ", "calculation", " ", "if", " ", "0"}]}]}], ",", 
     "  ", "otherwise", ",", " ", 
     RowBox[{
     "y", " ", "parameter", " ", "and", " ", "damping", " ", "scales", "  ", 
      "are", " ", "reused", " ", "from", " ", "previous", " ", "runs"}], ",", 
     " ", 
     RowBox[{"saves", " ", "lot", " ", "of", " ", "time"}]}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"reuse", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"ytozfile", "=", "\"\<ytoz_reuse.dat\>\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{"ztotfile", "=", "\"\<ztot_reuse.dat\>\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{"dampfile", "=", "\"\<kD_reuse.dat\>\""}], ";"}], "\n", 
   RowBox[{
    RowBox[{"tefile", "=", "\"\<te_reuse.dat\>\""}], ";"}], "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{
    "Whether", " ", "use", " ", "approximate", " ", "weights", " ", "or", " ",
      "do", " ", "the", " ", "integral", " ", "to", " ", "calculate", " ", 
     "energy", " ", "release"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"precision", "=", "0"}], ";"}], "\n", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{
      "Calculate", " ", "for", " ", "Silk", " ", "Damping", " ", "mode"}], 
      "=", "0"}], ",", " ", 
     RowBox[{
      RowBox[{"dark", " ", "matter", " ", "decay", "  ", "mode"}], "=", "1"}],
      ",", " ", 
     RowBox[{
      RowBox[{"custom", " ", "energy", " ", "injection", "  ", "mode"}], "=", 
      "2"}]}], " ", "*)"}], "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
     "If", " ", "mode", " ", "is", " ", "not", " ", "equal", " ", "to", " ", 
      "any", " ", "of", " ", "these", " ", "values"}], ",", " ", 
     RowBox[{
     "only", " ", "adiabatic", " ", "cooling", " ", "is", " ", 
      "calculates"}]}], " ", "*)"}], "\n", "\n", 
   RowBox[{
    RowBox[{"mode", "=", 
     RowBox[{"-", "1"}]}], ";"}], "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{
    "Silk", " ", "damping", " ", "parameters", " ", "for", " ", "power", " ", 
     "spectrum"}], " ", "*)"}], "\n", 
   RowBox[{"(*", 
    RowBox[{
    "Spectral", " ", "index", " ", "on", " ", "small", " ", "scales"}], 
    "*)"}], "\n", 
   RowBox[{
    RowBox[{"ns", "=", "1.5"}], ";"}], "\n", 
   RowBox[{"(*", " ", "Amplitude", " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{"A\[Zeta]", "=", 
     RowBox[{"1.61", "*", 
      RowBox[{"10", "^", 
       RowBox[{"-", "9"}]}]}]}], ";"}], "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"pivot", " ", "point", " ", "in", " ", "Mpc"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"k0Mpc", "=", "42.0"}], ";"}], "\n", "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"Dark", " ", "matter", " ", "decay", " ", "parameters"}], " ", 
    "*)"}], "\n", "\n", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"specify", " ", "either", " ", "decay", " ", "redshift", " ", 
      RowBox[{"(", 
       RowBox[{"zORt", "=", "0"}], ")"}], " ", "or", " ", "lifetime", " ", 
      "\[Tau]decay", " ", 
      RowBox[{"(", 
       RowBox[{"zORt", "=", "1"}], ")"}]}], ",", " ", 
     RowBox[{
      RowBox[{
       SubscriptBox["n", "dm"], 
       RowBox[{"(", "t", ")"}]}], "=", 
      RowBox[{
       SubscriptBox["n", "dm"], 
       RowBox[{"(", "initial", ")"}], "*", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "t"}], "/", "\[Tau]decay"}]]}]}], ",", " ", 
     RowBox[{"zdecay", " ", "is", " ", "defined", " ", "by"}], " ", ",", " ", 
     
     RowBox[{"\[Tau]decay", "=", 
      RowBox[{
       SuperscriptBox[
        SubscriptBox["\[Integral]", "\[Infinity]"], "zdecay"], "dt"}]}], ",", 
     " ", 
     RowBox[{"t", " ", "is", " ", "proper", " ", 
      RowBox[{"time", "."}]}]}], " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{"zORt", "=", "0"}], ";"}], "\n", 
   RowBox[{"(*", 
    RowBox[{"decay", " ", "redshift"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"zdecay", "=", 
     RowBox[{"7.0", "*", 
      RowBox[{"10", "^", "4"}]}]}], ";"}], "\n", 
   RowBox[{"(*", 
    RowBox[{"decay", " ", "time"}], " ", "*)"}], "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"\[Tau]decay", "=", 
      RowBox[{"time", "[", "zdecay", "]"}]}], ";"}], "*)"}], "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"amplitude", " ", "of", " ", "distortion"}], "=", " ", 
     FractionBox[
      RowBox[{
       SubscriptBox["f", "\[Gamma]"], 
       SubscriptBox["n", "X0"], 
       SubscriptBox["m", "X"], 
       SuperscriptBox["c", "2"]}], 
      RowBox[{
       SubscriptBox["a", "R"], 
       SuperscriptBox["TCMB", "4"], 
       RowBox[{"(", 
        RowBox[{"1", "+", "zdecay"}], ")"}]}]]}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"amplitude", "=", 
     SuperscriptBox["10", 
      RowBox[{"-", "7"}]]}], ";"}], "\n", "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"Custom", " ", "energy", " ", "release", " ", 
     RowBox[{"dQ", "/", "dz"}]}], " ", "*)"}], "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"Dark", " ", "matter", " ", "annihilation", " ", "example"}], " ",
     "*)"}], "\n", 
   RowBox[{
    RowBox[{"\[Sigma]v", "=", 
     FractionBox[
      RowBox[{"3", "*", 
       SuperscriptBox["10", 
        RowBox[{"-", "27"}]]}], 
      RowBox[{"\[CapitalOmega]cdm", " ", 
       SuperscriptBox["h0", "2"]}]]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"mdm", "=", 
     RowBox[{"10", " ", 
      RowBox[{"GeV", "/", 
       SuperscriptBox["c", "2"]}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"ndm", "[", "z_", "]"}], "=", 
     RowBox[{"\[Rho]cr", "*", 
      RowBox[{"\[CapitalOmega]cdm", "/", "mdm"}], " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", "z"}], ")"}], "3"]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"f\[Gamma]", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"dQdzCustom", "[", "z_", "]"}], "=", " ", 
     RowBox[{"f\[Gamma]", " ", 
      FractionBox[
       RowBox[{"mdm", " ", 
        SuperscriptBox["c", "2"], 
        SuperscriptBox[
         RowBox[{"ndm", "[", "z", "]"}], "2"], " ", "\[Sigma]v"}], 
       RowBox[{"a", " ", 
        SuperscriptBox["TCMB", "4"], 
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"1", "+", "z"}], ")"}], "5"], 
        RowBox[{"H", "[", "z", "]"}]}]]}]}], ";"}], "\n", "\n", 
   RowBox[{"(*", 
    RowBox[{"Physical", " ", "constants"}], " ", "*)"}], "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"Compton", " ", "scattering", " ", "crossections"}], " ", "*)"}], 
   "\n", 
   RowBox[{
    RowBox[{"\[Sigma]T", "=", 
     RowBox[{"6.65246", "*", 
      RowBox[{"10", "^", 
       RowBox[{"(", 
        RowBox[{"-", "25"}], ")"}]}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Sigma]", "[", "x_", "]"}], ":=", 
     RowBox[{"\[Sigma]T", "*", 
      RowBox[{"3", "/", "4"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1.", "+", "x"}], ")"}], "/", 
          RowBox[{"x", "^", "3"}]}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"2", " ", "x", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "x"}], ")"}]}], ")"}], "/", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              RowBox[{"2", " ", "x"}]}], ")"}]}], "-", 
           RowBox[{"Log", "[", 
            RowBox[{"1", "+", 
             RowBox[{"2", " ", "x"}]}], "]"}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"1", "/", 
          RowBox[{"(", 
           RowBox[{"2", " ", "x"}], ")"}]}], " ", 
         RowBox[{"Log", "[", 
          RowBox[{"1", "+", 
           RowBox[{"2", " ", "x"}]}], "]"}]}], "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"1", "+", 
           RowBox[{"3", " ", "x"}]}], ")"}], "/", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", 
            RowBox[{"2", " ", "x"}]}], ")"}], "^", "2"}]}]}], ")"}]}]}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{"G", "=", 
     RowBox[{"6.6742", "*", 
      RowBox[{"10", "^", 
       RowBox[{"(", 
        RowBox[{"-", "8"}], ")"}]}]}]}], ";"}], 
   RowBox[{"(*", "cgs", "*)"}], "\n", 
   RowBox[{
    RowBox[{"a", "=", 
     RowBox[{"7.5658", "*", 
      RowBox[{"10", "^", 
       RowBox[{"(", 
        RowBox[{"-", "15"}], ")"}]}]}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"radiation", " ", "constant", " ", "cgs"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"c", "=", 
     RowBox[{"2.99792458", "*", 
      RowBox[{"10", "^", 
       RowBox[{"(", "10", ")"}]}]}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"cm", "/", "s"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"parsec", "=", 
     RowBox[{"3.0856776", "*", 
      RowBox[{"10", "^", 
       RowBox[{"(", "18", ")"}]}]}]}], ";"}], 
   RowBox[{"(*", "cm", "*)"}], "\n", 
   RowBox[{
    RowBox[{"mparsec", "=", 
     RowBox[{"parsec", "*", 
      RowBox[{"10", "^", "6"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"\[Alpha]fs", "=", 
     RowBox[{"1", "/", "137.036"}]}], ";"}], 
   RowBox[{"(*", " ", 
    RowBox[{"Fine", " ", "structure", " ", "constant"}], " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{"kb", "=", 
     RowBox[{"1.3806505", "*", 
      RowBox[{"10", "^", 
       RowBox[{"(", 
        RowBox[{"-", "16"}], ")"}]}]}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"Boltzmann", " ", "cgs"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"hb", "=", 
     RowBox[{"1.05457168", "*", 
      RowBox[{"10", "^", 
       RowBox[{"(", 
        RowBox[{"-", "27"}], ")"}]}]}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Planck", "/", "2"}], "\[Pi]", " ", "cgs"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"h", "=", 
     RowBox[{"2", "*", "\[Pi]", "*", "hb"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"me", "=", 
     RowBox[{"9.1093826", "*", 
      RowBox[{"10", "^", 
       RowBox[{"(", 
        RowBox[{"-", "28"}], ")"}]}]}]}], ";"}], 
   RowBox[{"(*", 
    RowBox[{"mass", " ", "of", " ", "electron", " ", "g"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"ev", "=", 
     RowBox[{"1.60217646", "*", 
      SuperscriptBox["10", 
       RowBox[{"-", "12"}]]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"GeV", "=", 
     RowBox[{"ev", "*", 
      SuperscriptBox["10", "9"]}]}], ";"}], "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Helium", " ", "fraction", " ", "Y"}], "=", "0.24"}], "*)"}], 
   "\n", 
   RowBox[{"(*", " ", 
    RowBox[{"Total", " ", "Matter", " ", "density"}], " ", "*)"}], "\n", "\n", 
   RowBox[{
    RowBox[{"\[CapitalOmega]m", "=", 
     RowBox[{"\[CapitalOmega]cdm", "+", "\[CapitalOmega]b"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"H0", "=", 
     RowBox[{"h0", "*", "100", "*", "3.24077649", "*", 
      RowBox[{"10", "^", 
       RowBox[{"(", 
        RowBox[{"-", "20"}], ")"}]}]}]}], " ", ";"}], 
   RowBox[{"(*", 
    RowBox[{"s", "^", 
     RowBox[{"-", "1"}]}], "*)"}], " ", "\n", 
   RowBox[{
    RowBox[{"fHe", "=", 
     RowBox[{"fmHe", "/", 
      RowBox[{"(", 
       RowBox[{"3.9715", "*", "0.76"}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"fnu", "=", 
     RowBox[{"Nnu", "*", 
      RowBox[{"7.0", "/", "8"}], " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"4", "/", "11"}], ")"}], "^", 
       RowBox[{"(", 
        RowBox[{"4", "/", "3"}], ")"}]}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"zeq", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"3", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"H0", " ", "*", "c"}], ")"}], "^", "2"}], " ", "*", " ", 
         "\[CapitalOmega]m"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"8", " ", "\[Pi]", " ", "G", " ", "a", " ", 
         RowBox[{"TCMB", "^", "4"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "fnu"}], ")"}]}], ")"}]}], "-", "1"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"\[CapitalOmega]r", "=", 
     RowBox[{"\[CapitalOmega]m", "/", 
      RowBox[{"(", 
       RowBox[{"1", "+", "zeq"}], ")"}]}]}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"H", "[", "x_", "]"}], ":=", 
     RowBox[{"H0", "*", 
      RowBox[{"Sqrt", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "x"}], ")"}], "^", "4"}], " ", "*", " ", 
         "\[CapitalOmega]r"}], "+", 
        RowBox[{"\[CapitalOmega]m", " ", "*", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "x"}], ")"}], "^", "3"}]}], "+", 
        RowBox[{"(", 
         RowBox[{"1", "-", 
          RowBox[{"(", 
           RowBox[{"\[CapitalOmega]m", "+", "\[CapitalOmega]r"}], ")"}]}], 
         ")"}]}], "]"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"\[Rho]cr", "=", 
     RowBox[{"1", "/", 
      RowBox[{"(", 
       RowBox[{"8", " ", 
        RowBox[{"\[Pi]", "/", "3"}], "*", 
        RowBox[{"G", "/", 
         RowBox[{
          RowBox[{"H", "[", "0", "]"}], "^", "2"}]}]}], ")"}]}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"time", "[", "z_", "]"}], ":=", 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{"1", "/", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "x"}], ")"}], "*", 
          RowBox[{"H", "[", "x", "]"}]}], ")"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "z", ",", 
         RowBox[{"Max", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"10", "^", "4"}], "*", "z"}], ",", 
           SuperscriptBox["10", "5"]}], "]"}]}], "}"}], ",", 
       RowBox[{"Method", "->", 
        RowBox[{"{", 
         RowBox[{"\"\<GlobalAdaptive\>\"", ",", 
          RowBox[{"Method", "->", 
           RowBox[{"{", 
            RowBox[{"\"\<TrapezoidalRule\>\"", ",", 
             RowBox[{"\"\<RombergQuadrature\>\"", "->", "True"}]}], "}"}]}]}],
          "}"}]}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"nH", "[", "z_", "]"}], ":=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "z"}], ")"}], "^", "3"}], "*", "\[CapitalOmega]b", 
      "*", ".76", "*", 
      RowBox[{"\[Rho]cr", "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"1.67262", "*", 
          RowBox[{"10", "^", 
           RowBox[{"(", 
            RowBox[{"-", "24"}], ")"}]}]}], "+", 
         RowBox[{"9.1", "*", 
          RowBox[{"10", "^", 
           RowBox[{"(", 
            RowBox[{"-", "28"}], ")"}]}]}]}], ")"}]}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"nHe", "[", "z_", "]"}], ":=", 
     RowBox[{
      RowBox[{"nH", "[", "z", "]"}], "*", "fHe"}]}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{"xedata", "=", 
     RowBox[{"ReadList", "[", 
      RowBox[{"xefile", ",", 
       RowBox[{"{", 
        RowBox[{"Real", ",", "Real"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"xein", "=", 
     RowBox[{"Interpolation", "[", 
      RowBox[{"xedata", ",", 
       RowBox[{"InterpolationOrder", "->", "2"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"xezmax", "=", 
     RowBox[{"Max", "[", 
      RowBox[{
       RowBox[{"First", "[", 
        RowBox[{"First", "[", "xedata", "]"}], "]"}], ",", 
       RowBox[{"First", "[", 
        RowBox[{"Last", "[", "xedata", "]"}], "]"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"xhighz", "=", 
     RowBox[{"xein", "[", "xezmax", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"xezmin", "=", 
     RowBox[{"Min", "[", 
      RowBox[{
       RowBox[{"First", "[", 
        RowBox[{"First", "[", "xedata", "]"}], "]"}], ",", 
       RowBox[{"First", "[", 
        RowBox[{"Last", "[", "xedata", "]"}], "]"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"xezmin", ">", "101"}], ",", 
      RowBox[{
       RowBox[{
       "Print", "[", 
        "\"\<Warning: Minimum redshift in recombination history must be <=100\
\>\"", "]"}], ";", 
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Input file has minimum redshift z=\>\"", ",", "xezmin"}],
         "]"}], ";", " ", 
       RowBox[{"Exit", "[", "]"}], ";"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"xe", "[", "z_", "]"}], "=", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"z", "<", "xezmax"}], ",", 
       RowBox[{"xein", "[", "z", "]"}], ",", "xhighz"}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"ne", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"xe", "[", "z", "]"}], "*", 
      RowBox[{"nH", "[", "z", "]"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"bigA", "=", 
     RowBox[{"kb", "*", 
      RowBox[{"\[Sigma]T", "/", 
       RowBox[{"(", 
        RowBox[{"me", "*", "c"}], ")"}]}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"yy", "[", "z_", "]"}], ":=", 
     RowBox[{"NIntegrate", "[", 
      RowBox[{
       RowBox[{"bigA", "*", 
        RowBox[{"ne", "[", "x", "]"}], "*", "TCMB", "*", 
        RowBox[{"(", 
         RowBox[{"1", "+", "x"}], ")"}], "*", 
        RowBox[{"1", "/", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"H", "[", "x", "]"}], "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "x"}], ")"}]}], ")"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "xezmin", ",", "z"}], "}"}], ",", 
       RowBox[{"Method", "->", 
        RowBox[{"{", 
         RowBox[{"\"\<GlobalAdaptive\>\"", ",", 
          RowBox[{"Method", "->", 
           RowBox[{"{", "\"\<GaussKronrodRule\>\"", "}"}]}], ",", 
          RowBox[{"\"\<SingularityDepth\>\"", "->", "\[Infinity]"}]}], 
         "}"}]}], ",", 
       RowBox[{"PrecisionGoal", "->", "6"}], ",", 
       RowBox[{"MaxRecursion", "->", "15"}]}], "]"}]}], ";"}], "\n", "\n", 
   "\n", 
   RowBox[{
    RowBox[{"izmax", "=", "1000"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"dz", "=", 
     RowBox[{"1.0", "*", 
      RowBox[{
       RowBox[{"Log", "[", 
        RowBox[{"zmax", "/", "zmin"}], "]"}], "/", "izmax"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"reuse", "\[Equal]", "0"}], ",", "\n", 
      RowBox[{
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "<=", 
          RowBox[{"izmax", "+", "1"}]}], ",", 
         RowBox[{"i", "++"}], ",", "\n", "    ", 
         RowBox[{
          RowBox[{
           RowBox[{"zsamp", "[", "i", "]"}], "=", 
           RowBox[{"Exp", "[", 
            RowBox[{
             RowBox[{"Log", "[", "zmin", "]"}], "+", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{"i", "-", "1"}], ")"}], "*", "dz"}]}], "]"}]}], ";", 
          "\n", "    ", 
          RowBox[{
           RowBox[{"ysamp", "[", "i", "]"}], "=", 
           RowBox[{"Log", "[", 
            RowBox[{"yy", "[", 
             RowBox[{"zsamp", "[", "i", "]"}], "]"}], "]"}]}], ";", "\n", 
          "    ", 
          RowBox[{
           RowBox[{"tsamp", "[", "i", "]"}], "=", 
           RowBox[{"Log", "[", 
            RowBox[{"time", "[", 
             RowBox[{"zsamp", "[", "i", "]"}], "]"}], "]"}]}], ";"}]}], "\n", 
        "    ", "]"}], ";", "\n", 
       RowBox[{"ytozdata", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"ysamp", "[", "i", "]"}], ",", 
             RowBox[{"Log", "[", 
              RowBox[{"zsamp", "[", "i", "]"}], "]"}]}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"izmax", "+", "1"}]}], "}"}]}], "]"}]}], ";", "\n", 
       RowBox[{"ztotdata", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Log", "[", 
              RowBox[{"zsamp", "[", "i", "]"}], "]"}], ",", 
             RowBox[{"tsamp", "[", "i", "]"}]}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"izmax", "+", "1"}]}], "}"}]}], "]"}]}], ";", "\n", 
       RowBox[{"Export", "[", 
        RowBox[{"ytozfile", ",", "ytozdata"}], "]"}], ";", "\n", 
       RowBox[{"Export", "[", 
        RowBox[{"ztotfile", ",", "ztotdata"}], "]"}], ";"}], ",", "\n", 
      RowBox[{
       RowBox[{"ytozdata", "=", 
        RowBox[{"ReadList", "[", 
         RowBox[{"ytozfile", ",", 
          RowBox[{"{", 
           RowBox[{"Real", ",", "Real"}], "}"}]}], "]"}]}], ";", "\n", 
       RowBox[{"ztotdata", "=", 
        RowBox[{"ReadList", "[", 
         RowBox[{"ztotfile", ",", 
          RowBox[{"{", 
           RowBox[{"Real", ",", "Real"}], "}"}]}], "]"}]}], ";"}]}], "\n", 
     "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"zdata", "=", 
     RowBox[{"Part", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", "ztotdata", "]"}], ",", "1"}], "]"}]}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{"tdata", "=", 
     RowBox[{"Part", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", "ztotdata", "]"}], ",", "2"}], "]"}]}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{"ttozdata", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"tdata", ",", "zdata"}], "}"}], "]"}]}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{"ytozint", "=", 
     RowBox[{"Interpolation", "[", "ytozdata", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"ztotint", "=", 
     RowBox[{"Interpolation", "[", "ztotdata", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"ttozint", "=", 
     RowBox[{"Interpolation", "[", "ttozdata", "]"}]}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"ytoz", "[", "y_", "]"}], "=", 
     RowBox[{"Exp", "[", 
      RowBox[{"ytozint", "[", 
       RowBox[{"Log", "[", "y", "]"}], "]"}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"ztot", "[", "z_", "]"}], "=", 
     RowBox[{"Exp", "[", 
      RowBox[{"ztotint", "[", 
       RowBox[{"Log", "[", "z", "]"}], "]"}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"ttoz", "[", "z_", "]"}], "=", 
     RowBox[{"Exp", "[", 
      RowBox[{"ttozint", "[", 
       RowBox[{"Log", "[", "z", "]"}], "]"}], "]"}]}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{
    "Print", "[", "\"\<Solving ODE for Electron temperature\>\"", "]"}], 
    ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"coolcomp", "[", "z_", "]"}], ":=", 
     RowBox[{"8", " ", "\[Sigma]T", " ", "a", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"TCMB", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "z"}], ")"}]}], ")"}], "^", "4"}], " ", 
      RowBox[{
       RowBox[{"xe", "[", "z", "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"3", "*", "me", " ", "c", "*", 
         RowBox[{"(", 
          RowBox[{"1.0", "+", "fHe", "+", 
           RowBox[{"xe", "[", "z", "]"}]}], ")"}]}], ")"}]}]}]}], ";"}], "\n",
    "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"reuse", "\[Equal]", "0"}], ",", "\n", 
      RowBox[{
       RowBox[{"solrho", "=", 
        RowBox[{"NDSolve", "[", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{
             RowBox[{"D", "[", 
              RowBox[{
               RowBox[{"\[Rho]", "[", "z", "]"}], ",", "z"}], "]"}], "==", 
             RowBox[{
              RowBox[{
               RowBox[{
                RowBox[{"-", "1"}], "/", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"H", "[", "z", "]"}], "*", 
                  RowBox[{"(", 
                   RowBox[{"1", "+", "z"}], ")"}]}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"coolcomp", "[", "z", "]"}], "*", 
                 RowBox[{"(", 
                  RowBox[{"1.0", "-", 
                   RowBox[{"\[Rho]", "[", "z", "]"}]}], ")"}]}], ")"}]}], "+", 
              RowBox[{
               RowBox[{"\[Rho]", "[", "z", "]"}], "/", 
               RowBox[{"(", 
                RowBox[{"1", "+", "z"}], ")"}]}]}]}], ",", 
            RowBox[{
             RowBox[{"\[Rho]", "[", 
              RowBox[{"zmax", "*", "1.1"}], "]"}], "==", "1.0"}]}], "}"}], 
          ",", "\[Rho]", ",", 
          RowBox[{"{", 
           RowBox[{"z", ",", "zmin", ",", 
            RowBox[{"zmax", "*", "1.1"}]}], "}"}], ",", 
          RowBox[{"Method", "->", 
           RowBox[{"{", 
            RowBox[{"\"\<BDF\>\"", ",", 
             RowBox[{"\"\<MaxDifferenceOrder\>\"", "->", "2"}], ",", 
             RowBox[{"\"\<VariableStepCoefficients\>\"", "->", "True"}]}], 
            "}"}]}], ",", 
          RowBox[{"AccuracyGoal", "->", "15"}], ",", 
          RowBox[{"MaxStepFraction", "->", 
           RowBox[{"10", "^", 
            RowBox[{"-", "5"}]}]}], ",", 
          RowBox[{"MaxSteps", "->", 
           RowBox[{"10", "^", "7"}]}], ",", 
          RowBox[{"InterpolationOrder", "->", "All"}]}], "]"}]}], ";", "\n", 
       RowBox[{"Tetbl", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"Flatten", "[", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"Log", "[", 
              RowBox[{"zsamp", "[", "i", "]"}], "]"}], ",", 
             RowBox[{"Log", "[", 
              RowBox[{
               RowBox[{"1.0", "-", 
                RowBox[{"\[Rho]", "[", 
                 RowBox[{"zsamp", "[", "i", "]"}], "]"}]}], "/.", "solrho"}], 
              "]"}]}], "}"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "1", ",", 
            RowBox[{"izmax", "+", "1"}]}], "}"}]}], "]"}]}], ";", "\n", 
       RowBox[{"Export", "[", 
        RowBox[{"tefile", ",", "Tetbl"}], "]"}], ";"}], ",", "\n", 
      RowBox[{
       RowBox[{"Tetbl", "=", 
        RowBox[{"ReadList", "[", 
         RowBox[{"tefile", ",", 
          RowBox[{"{", 
           RowBox[{"Real", ",", "Real"}], "}"}]}], "]"}]}], ";"}]}], "]"}], 
    ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{"teint", "=", 
     RowBox[{"Interpolation", "[", "Tetbl", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"tgminuste", "[", "z_", "]"}], "=", 
     RowBox[{"Exp", "[", 
      RowBox[{"teint", "[", 
       RowBox[{"Log", "[", "z", "]"}], "]"}], "]"}]}], ";"}], "\n", "\n", 
   "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"Calculate", " ", "Blackbody", " ", "Optical", " ", "depth"}], 
     ",", " ", 
     RowBox[{"see", "  ", 
      RowBox[{"arXiv", ":", 
       RowBox[{"1203.2601", " ", "for", " ", "details"}]}]}]}], "*)"}], "\n", 
   
   RowBox[{
    RowBox[{
     RowBox[{"dcompton", "[", "z_", "]"}], ":=", 
     RowBox[{"1.005", "*", 
      RowBox[{"ne", "[", "z", "]"}], "*", "\[Sigma]T", " ", "c", "  ", "4", 
      "*", 
      RowBox[{"\[Alpha]fs", "/", 
       RowBox[{"(", 
        RowBox[{"3", "*", "\[Pi]"}], ")"}]}], "*", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"kb", " ", "*", "TCMB", "*", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"1", "+", "z"}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"me", "*", 
            RowBox[{"c", "^", "2"}]}], ")"}]}]}], ")"}], "2"], "*", 
      "25.976"}]}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"kcomp", "[", "z_", "]"}], "=", 
     RowBox[{"c", " ", 
      RowBox[{"ne", "[", "z", "]"}], " ", "\[Sigma]T", " ", "kb", " ", "TCMB",
       " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "z"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"me", " ", 
         RowBox[{"c", "^", "2"}]}], ")"}]}]}]}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"brehm", "[", "z_", "]"}], ":=", " ", 
     RowBox[{"2.99", "*", 
      RowBox[{"ne", "[", "z", "]"}], "*", "\[Sigma]T", " ", "c", 
      FractionBox[
       RowBox[{" ", 
        RowBox[{"\[Alpha]fs", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"nH", "[", "z", "]"}], "+", 
           RowBox[{"4", "*", 
            RowBox[{"nHe", "[", "z", "]"}]}]}], ")"}]}]}], 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{"24", " ", 
          SuperscriptBox["\[Pi]", "3"]}], ")"}], 
        RowBox[{"1", "/", "2"}]]], "*", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{"(", 
          RowBox[{"me", " ", "*", 
           RowBox[{"c", "^", "2"}]}], ")"}], 
         RowBox[{" ", 
          RowBox[{"kb", " ", "*", "TCMB", " ", "*", 
           RowBox[{"(", 
            RowBox[{"1", "+", "z"}], ")"}]}]}]], ")"}], 
       RowBox[{"7", "/", "2"}]], " ", "*", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["h", 
         RowBox[{"me", " ", "c"}]], ")"}], "3"]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"ztau", "=", 
     RowBox[{"1.96", "*", 
      SuperscriptBox["10", "6"]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"abr", "=", 
     FractionBox[
      RowBox[{"brehm", "[", "ztau", "]"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", "ztau"}], ")"}], 
       RowBox[{"5", "/", "2"}]]]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"adC", "=", 
     FractionBox[
      RowBox[{"dcompton", "[", "ztau", "]"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", "ztau"}], ")"}], "5"]]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"aC", "=", 
     FractionBox[
      RowBox[{"kcomp", "[", "ztau", "]"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"1", "+", "ztau"}], ")"}], "4"]]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"kC", "=", "0.7768"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"aH", "=", 
     RowBox[{"(", 
      RowBox[{"\[CapitalOmega]r", " ", 
       SuperscriptBox["H0", "2"]}], ")"}]}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{"zbr", "=", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox[
        RowBox[{"25", " ", "aH"}], 
        RowBox[{"4", " ", 
         SuperscriptBox["kC", "2"], "aC", "*", "abr"}]], ")"}], 
      RowBox[{"2", "/", "5"}]]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zdC", "=", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox[
        RowBox[{"25", " ", "aH"}], 
        RowBox[{"4", " ", 
         SuperscriptBox["kC", "2"], "aC", "*", "adC"}]], ")"}], 
      RowBox[{"1", "/", "5"}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"z\[Epsilon]", "=", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["abr", "adC"], ")"}], 
      RowBox[{"2", "/", "5"}]]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"\[Epsilon]", "=", 
     FractionBox[
      RowBox[{"kC", " ", "2", " ", "abr", " "}], 
      RowBox[{"5", " ", 
       SqrtBox[
        FractionBox[
         RowBox[{"adC", " ", "aH"}], "aC"]]}]]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zbr22", "=", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox[
        SuperscriptBox["aH", 
         RowBox[{"1", "/", "2"}]], 
        RowBox[{"2", " ", "abr", " ", "kC", " ", "*", "2.958", " "}]], ")"}], 
      "2"]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"zdc22", "=", " ", 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox[
        RowBox[{"3", " ", 
         SuperscriptBox["aH", 
          RowBox[{"1", "/", "2"}]]}], 
        RowBox[{" ", 
         RowBox[{"adC", " ", "kC", " ", "*", "2.958", " "}]}]], ")"}], 
      RowBox[{"1", "/", "3"}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"tau1", "[", "z_", "]"}], "=", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{"1", "+", "z"}], 
            RowBox[{"1", "+", "zdC"}]], ")"}], "5"], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{"1", "+", "z"}], 
            RowBox[{"1", "+", "zbr"}]], ")"}], 
          RowBox[{"5", "/", "2"}]]}], ")"}], 
       RowBox[{"1", "/", "2"}]], "+", 
      RowBox[{"\[Epsilon]", " ", 
       RowBox[{"Log", "[", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox[
            RowBox[{"1", "+", "z"}], 
            RowBox[{"1", "+", "z\[Epsilon]"}]], ")"}], 
          RowBox[{"5", "/", "4"}]], "+", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox[
             RowBox[{"(", 
              FractionBox[
               RowBox[{"1", "+", "z"}], 
               RowBox[{"1", "+", "z\[Epsilon]"}]], ")"}], 
             RowBox[{"5", "/", "2"}]]}], ")"}], 
          RowBox[{"1", "/", "2"}]]}], "]"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"tau2", "[", "z_", "]"}], "=", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "+", "z"}], 
         RowBox[{"1", "+", "zbr22"}]], ")"}], 
       RowBox[{"1", "/", "2"}]], "+", 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{"1", "+", "z"}], 
         RowBox[{"1", "+", "zdc22"}]], ")"}], "3"]}]}], ";"}], "\n", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"tau", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"1.007", " ", 
       RowBox[{"tau1", "[", "z", "]"}]}], "+", 
      RowBox[{"tau2", "[", "z", "]"}]}]}], ";"}], "\[IndentingNewLine]", "\n",
    "\n", 
   RowBox[{
    RowBox[{"xmin", "=", 
     RowBox[{"10", "^", 
      RowBox[{"(", 
       RowBox[{"-", "5"}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"xmax", "=", "120.0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"zzmin", "=", 
     RowBox[{"Log", "[", "xmin", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"zzmax", "=", 
     RowBox[{"Log", "[", "xmax", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"nbb", "[", "x_", "]"}], "=", 
     RowBox[{"1.0", "/", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Exp", "[", "x", "]"}], "-", "1.0"}], ")"}]}]}], ";"}], "\n", 
   "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"nszsol", "[", "x_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"x", " ", 
         RowBox[{"Exp", "[", "x", "]"}]}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Exp", "[", "x", "]"}], "-", "1"}], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"x", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Exp", "[", "x", "]"}], "+", "1"}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"Exp", "[", "x", "]"}], "-", "1"}], ")"}]}]}], "-", "4"}],
        ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"musol", "[", "x_", "]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"Exp", "[", "x", "]"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Exp", "[", "x", "]"}], "-", "1"}], ")"}]}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"x", "/", "2.19"}], "-", "1"}], ")"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"dydz", "[", "z_", "]"}], "=", 
     RowBox[{"kb", " ", "\[Sigma]T", " ", 
      RowBox[{"ne", "[", "z", "]"}], "TCMB", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "+", "z"}], ")"}], "/", 
       RowBox[{"(", 
        RowBox[{"me", " ", "c", " ", 
         RowBox[{"H", "[", "z", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "z"}], ")"}]}], ")"}]}]}]}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"mode", "\[Equal]", "0"}], ",", "\n", 
      RowBox[{"(*", 
       RowBox[{"Silk", " ", "Damping", " ", "setup"}], "*)"}], "\n", 
      RowBox[{
       RowBox[{
        RowBox[{"R", "[", "z_", "]"}], " ", ":=", " ", 
        RowBox[{
         RowBox[{"3", "/", "4"}], " ", "*", 
         RowBox[{"\[CapitalOmega]b", "/", 
          RowBox[{"(", 
           RowBox[{"\[CapitalOmega]r", "*", 
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", "z"}], ")"}]}], ")"}]}]}]}], ";", 
       "\n", 
       RowBox[{
        RowBox[{"dkddzdamp", "[", "z_", "]"}], " ", ":=", " ", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"c", "*", 
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", "z"}], ")"}]}], ")"}], "/", 
          RowBox[{"(", 
           RowBox[{"6", "*", 
            RowBox[{"H", "[", "z", "]"}], "*", 
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", 
              RowBox[{"R", "[", "z", "]"}]}], ")"}], " ", 
            RowBox[{"ne", "[", "z", "]"}], "*", "\[Sigma]T"}], ")"}]}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{
             RowBox[{"R", "[", "z", "]"}], "^", "2"}], "/", 
            RowBox[{"(", 
             RowBox[{"1", " ", "+", " ", 
              RowBox[{"R", "[", "z", "]"}]}], ")"}]}], " ", "+", " ", 
           RowBox[{"16", "/", "15"}]}], ")"}]}]}], ";", "\n", 
       RowBox[{
        RowBox[{"okd2", "[", "z_", "]"}], " ", ":=", " ", 
        RowBox[{"NIntegrate", "[", 
         RowBox[{
          RowBox[{"dkddzdamp", "[", "zz", "]"}], ",", " ", 
          RowBox[{"{", 
           RowBox[{"zz", ",", " ", "z", ",", " ", "\[Infinity]"}], "}"}], ",",
           " ", 
          RowBox[{"Method", " ", "->", " ", 
           RowBox[{"{", 
            RowBox[{"\"\<GlobalAdaptive\>\"", ",", " ", 
             RowBox[{"Method", " ", "->", " ", 
              RowBox[{"{", "\"\<GaussKronrodRule\>\"", "}"}]}], ",", " ", 
             RowBox[{
             "\"\<SingularityDepth\>\"", " ", "->", " ", "\[Infinity]"}]}], 
            "}"}]}], ",", " ", 
          RowBox[{"PrecisionGoal", " ", "->", " ", "6"}], ",", " ", 
          RowBox[{"MaxRecursion", " ", "->", " ", "30"}]}], "]"}]}], ";", 
       "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"reuse", "\[Equal]", "0"}], ",", "\n", 
         RowBox[{
          RowBox[{"kdtbl", " ", "=", " ", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Flatten", "[", 
              RowBox[{"{", 
               RowBox[{"z", ",", " ", 
                RowBox[{"Log", "[", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"1", "/", 
                    RowBox[{"okd2", "[", 
                    RowBox[{"Exp", "[", "z", "]"}], "]"}]}], ")"}], "^", 
                  RowBox[{"(", 
                   RowBox[{"1", "/", "2"}], ")"}]}], "]"}]}], "}"}], "]"}], 
             ",", " ", 
             RowBox[{"{", 
              RowBox[{"z", ",", " ", 
               RowBox[{"Log", "[", "1000.0", "]"}], ",", " ", 
               RowBox[{"Log", "[", "zmax", "]"}], ",", " ", 
               RowBox[{
                RowBox[{"Log", "[", 
                 RowBox[{"zmax", "/", "1000"}], "]"}], "/", "500.0"}]}], 
              "}"}]}], "]"}]}], ";", "\n", 
          RowBox[{"Export", "[", 
           RowBox[{"dampfile", ",", "kdtbl"}], "]"}], ";"}], ",", "\n", 
         RowBox[{
          RowBox[{"kdtbl", "=", 
           RowBox[{"ReadList", "[", 
            RowBox[{"dampfile", ",", 
             RowBox[{"{", 
              RowBox[{"Real", ",", "Real"}], "}"}]}], "]"}]}], ";"}]}], "\n", 
        "]"}], ";", "\n", 
       RowBox[{"kdint", " ", "=", " ", 
        RowBox[{"Interpolation", "[", "kdtbl", "]"}]}], ";", "\n", 
       RowBox[{
        RowBox[{"kd", "[", "z_", "]"}], " ", ":=", " ", 
        RowBox[{"Exp", "[", 
         RowBox[{"kdint", "[", 
          RowBox[{"Log", "[", "z", "]"}], "]"}], "]"}]}], ";", "\n", 
       RowBox[{"k0", "=", 
        RowBox[{"k0Mpc", "/", "mparsec"}]}], ";", "\n", 
       RowBox[{
        RowBox[{"dQdz", "[", "z_", "]"}], "=", 
        RowBox[{
         RowBox[{"3", "/", "4"}], "*", "4.3", " ", 
         RowBox[{"A\[Zeta]", "/", 
          RowBox[{"k0", "^", 
           RowBox[{"(", 
            RowBox[{"ns", "-", "1"}], ")"}]}]}], 
         RowBox[{"dkddzdamp", "[", "z", "]"}], " ", 
         RowBox[{"2", "^", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             RowBox[{"(", 
              RowBox[{"3", "+", "ns"}], ")"}]}], "/", "2"}], ")"}]}], " ", 
         RowBox[{
          RowBox[{"kd", "[", "z", "]"}], "^", 
          RowBox[{"(", 
           RowBox[{"ns", "+", "1"}], ")"}]}], " ", 
         RowBox[{"Gamma", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"ns", "+", "1"}], ")"}], "/", "2"}], "]"}]}]}], ";"}], 
      ",", "\n", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"mode", "\[Equal]", "1"}], ",", "\n", 
         RowBox[{"(*", " ", 
          RowBox[{"Particle", " ", "decay", " ", "setup"}], "*)"}], "\n", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"zORt", "\[Equal]", "0"}], ",", "\n", 
            RowBox[{
             RowBox[{"\[Tau]decay", "=", 
              RowBox[{"time", "[", "zdecay", "]"}]}], ";"}], ",", "\n", 
            RowBox[{
             RowBox[{"zdecay", "=", 
              RowBox[{"ttoz", "[", "\[Tau]decay", "]"}]}], ";"}]}], "\n", 
           "]"}], ";", "\n", 
          RowBox[{
           RowBox[{"dQdz", "[", "z_", "]"}], "=", 
           RowBox[{
            RowBox[{"10", "^", 
             RowBox[{"(", 
              RowBox[{"-", "7"}], ")"}]}], "*", 
            RowBox[{"(", 
             RowBox[{"1", "+", "zdecay"}], ")"}], 
            RowBox[{
             RowBox[{"Exp", "[", 
              RowBox[{
               RowBox[{"-", 
                RowBox[{"ztot", "[", "z", "]"}]}], "/", "\[Tau]decay"}], 
              "]"}], "/", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"H", "[", "z", "]"}], "*", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{"1", "+", "z"}], ")"}], "^", "2"}], "*", 
               "\[Tau]decay"}], ")"}]}]}]}], ";"}], ",", "\n", 
         RowBox[{
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"mode", "\[Equal]", "2"}], ",", "\n", 
            RowBox[{"(*", 
             RowBox[{"Custom", " ", "energy", " ", "release"}], " ", "*)"}], 
            "\n", 
            RowBox[{
             RowBox[{
              RowBox[{"dQdz", "[", "z_", "]"}], "=", 
              RowBox[{"dQdzCustom", "[", "z", "]"}]}], ";"}], ",", "\n", 
            RowBox[{
             RowBox[{
              RowBox[{"dQdz", "[", "z_", "]"}], "=", "0"}], ";"}]}], "\n", 
           "]"}], ";"}]}], "\n", "]"}], ";"}]}], "\n", "]"}], ";"}], "\n", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Take", " ", "into", " ", "account", " ", "adiabatic", " ", "cooling", 
     " ", "of", " ", "baryons"}], " ", "*)"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"dQdzcooly", "[", "z_", "]"}], "=", " ", 
     RowBox[{"4", " ", "kb", " ", "\[Sigma]T", "  ", 
      RowBox[{"(", 
       RowBox[{"TCMB", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "z"}], ")"}]}], ")"}], " ", 
      RowBox[{"ne", "[", "z", "]"}], "*", 
      RowBox[{
       RowBox[{"tgminuste", "[", "z", "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"me", " ", "c", "*", 
         RowBox[{"H", "[", "z", "]"}], 
         RowBox[{"(", 
          RowBox[{"1", "+", "z"}], ")"}]}], ")"}]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"dQdzcool", "[", "z_", "]"}], "=", 
     RowBox[{
      RowBox[{"3", "/", "2"}], " ", "kb", " ", "TCMB", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "z"}], ")"}], "*", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", "*", 
           RowBox[{"nH", "[", "z", "]"}]}], "+", 
          RowBox[{"3", "*", 
           RowBox[{"nHe", "[", "z", "]"}]}]}], ")"}], "/", 
        RowBox[{"(", 
         RowBox[{"a", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"TCMB", "*", 
             RowBox[{"(", 
              RowBox[{"1", "+", "z"}], ")"}]}], ")"}], "^", "4"}]}], ")"}]}], 
       "/", 
       RowBox[{"(", 
        RowBox[{"1", "+", "z"}], ")"}]}]}]}], ";"}], "\n", "\n", 
   RowBox[{
    RowBox[{"ystr", "=", "\"\<nkomp_ad_y5_itr_1_1901_\>\""}], ";"}], "\n", 
   "\n", 
   RowBox[{
    RowBox[{"y1", "=", "0.0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"k", "=", "0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{
     RowBox[{"yout", "[", "k", "]"}], "=", "y1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"y2", "=", "0.0"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"maxflag", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"minflag", "=", "1"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"While", "[", 
     RowBox[{
      RowBox[{"y2", "<=", "10.0"}], ",", "\n", "      ", 
      RowBox[{
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"y1", ">", "1.0"}], ",", 
         RowBox[{"\[Delta]y", "=", "0.01"}], ",", 
         RowBox[{"\[Delta]y", "=", "0.001"}]}], "]"}], ";", "\n", 
       RowBox[{"y2", "=", 
        RowBox[{"y1", "+", "\[Delta]y"}]}], ";", "\n", 
       RowBox[{"k", "=", 
        RowBox[{"k", "+", "1"}]}], ";", "\n", 
       RowBox[{
        RowBox[{"yout", "[", "k", "]"}], "=", "y2"}], ";", "\n", 
       RowBox[{"y1", "=", "y2"}], ";", "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"y2", "\[GreaterEqual]", "ymax"}], " ", "&&", " ", 
          RowBox[{"maxflag", "\[Equal]", "1"}]}], ",", 
         RowBox[{
          RowBox[{"imaxout", "=", "k"}], ";", 
          RowBox[{"maxflag", "=", "0"}], ";"}]}], "]"}], ";", "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"y2", "\[GreaterEqual]", "ymin"}], " ", "&&", " ", 
          RowBox[{"minflag", "\[Equal]", "1"}]}], ",", 
         RowBox[{
          RowBox[{"iminout", "=", "k"}], ";", 
          RowBox[{"minflag", "=", "0"}], ";"}]}], "]"}], ";"}]}], "\n", "]"}],
     ";"}], "\n", 
   RowBox[{
    RowBox[{"imax", "=", "k"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Total Files=\>\"", ",", "imax"}], "]"}], ";"}], "\n", 
   RowBox[{"(*", 
    RowBox[{"ymin", "=", "0.01"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<ymin=\>\"", ",", 
      RowBox[{"yout", "[", "iminout", "]"}]}], "]"}], ";"}], "\n", 
   RowBox[{"(*", 
    RowBox[{"ymax", "=", "2"}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<ymax=\>\"", ",", 
      RowBox[{"yout", "[", "imaxout", "]"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "iminout"}], ",", 
      RowBox[{"i", "<=", "imaxout"}], ",", 
      RowBox[{"i", "++"}], ",", "\n", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"Print", "[", 
         RowBox[{"\"\<i=\>\"", ",", "i"}], "]"}], ";"}], "*)"}], "\n", 
      RowBox[{
       RowBox[{"y2", "=", 
        RowBox[{"yout", "[", "i", "]"}]}], ";", "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"i", "\[Equal]", "imaxout"}], ",", 
         RowBox[{
          RowBox[{"yip1", "=", "y2"}], ";"}], ",", 
         RowBox[{
          RowBox[{"yip1", "=", 
           RowBox[{"yout", "[", 
            RowBox[{"i", "+", "1"}], "]"}]}], ";"}]}], "]"}], ";", "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"i", "\[Equal]", "iminout"}], ",", 
         RowBox[{
          RowBox[{"yim1", "=", "y2"}], ";"}], ",", 
         RowBox[{
          RowBox[{"yim1", "=", 
           RowBox[{"yout", "[", 
            RowBox[{"i", "-", "1"}], "]"}]}], ";"}]}], "]"}], ";", "\n", 
       RowBox[{"dy", "=", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"yip1", "-", "yim1"}], ")"}], "/", "2.0"}]}], ";", "\n", 
       RowBox[{"(*", 
        RowBox[{
         RowBox[{"Calculate", " ", "weights"}], " ", "=", 
         RowBox[{
          RowBox[{"energy", "/", "4"}], "*", 
          SuperscriptBox["10", "5"]}]}], "*)"}], "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"precision", "\[Equal]", "0"}], ",", "\n", 
         RowBox[{
          RowBox[{
           RowBox[{"yamplitude", "[", "i", "]"}], "=", 
           RowBox[{
            SuperscriptBox["10", "5"], "*", "0.25", "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"dQdz", "[", 
                RowBox[{"ytoz", "[", "y2", "]"}], "]"}], "-", 
               RowBox[{"dQdzcool", "[", 
                RowBox[{"ytoz", "[", "y2", "]"}], "]"}]}], ")"}], "/", 
             RowBox[{"dydz", "[", 
              RowBox[{"ytoz", "[", "y2", "]"}], "]"}]}], "*", "dy"}]}], ";"}],
          ",", "\n", 
         RowBox[{
          RowBox[{
           RowBox[{"yamplitude", "[", "i", "]"}], "=", " ", 
           RowBox[{
            SuperscriptBox["10", "5"], "*", "0.25", "*", 
            RowBox[{"NIntegrate", "[", 
             RowBox[{
              RowBox[{"(", 
               RowBox[{
                RowBox[{"dQdz", "[", "z", "]"}], "-", 
                RowBox[{"dQdzcool", "[", "z", "]"}]}], ")"}], ",", 
              RowBox[{"{", 
               RowBox[{"z", ",", 
                RowBox[{"ytoz", "[", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"y2", "+", "yim1"}], ")"}], "/", "2.0"}], "]"}], 
                ",", 
                RowBox[{"ytoz", "[", 
                 RowBox[{
                  RowBox[{"(", 
                   RowBox[{"yip1", "+", "y2"}], ")"}], "/", "2.0"}], "]"}]}], 
               "}"}], ",", 
              RowBox[{"Method", "->", 
               RowBox[{"{", 
                RowBox[{"\"\<GlobalAdaptive\>\"", ",", 
                 RowBox[{"Method", "->", 
                  RowBox[{"{", "\"\<GaussKronrodRule\>\"", "}"}]}], ",", 
                 RowBox[{"\"\<SingularityDepth\>\"", "->", "\[Infinity]"}]}], 
                "}"}]}], ",", 
              RowBox[{"PrecisionGoal", "->", "9"}], ",", 
              RowBox[{"MaxRecursion", "->", "20"}]}], "]"}]}]}], ";"}]}], 
        "\n", "]"}], ";", "\n", 
       RowBox[{"file", "=", 
        RowBox[{"OpenRead", "[", 
         RowBox[{"root", "<>", "ystr", "<>", 
          RowBox[{"ToString", "[", "y2", "]"}], "<>", "\"\<.dat\>\""}], 
         "]"}]}], ";", "\n", 
       RowBox[{"data", "=", 
        RowBox[{"ReadList", "[", 
         RowBox[{"file", ",", 
          RowBox[{"{", 
           RowBox[{"Real", ",", "Real"}], "}"}]}], "]"}]}], ";", "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"i", "\[Equal]", "imaxout"}], ",", " ", 
         RowBox[{
          RowBox[{"xdata", "=", 
           RowBox[{"Part", "[", 
            RowBox[{
             RowBox[{"Transpose", "[", "data", "]"}], ",", "1"}], "]"}]}], 
          ";"}]}], "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"nxdata", "=", 
        RowBox[{"Part", "[", 
         RowBox[{
          RowBox[{"Transpose", "[", "data", "]"}], ",", "2"}], "]"}]}], ";", 
       "\n", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"i", "\[Equal]", "iminout"}], ",", 
         RowBox[{
          RowBox[{"nx", "=", 
           RowBox[{
            RowBox[{"yamplitude", "[", "i", "]"}], "*", "nxdata"}]}], ";"}], 
         ",", "\n", 
         RowBox[{
          RowBox[{"nx", "=", 
           RowBox[{"nx", "+", 
            RowBox[{
             RowBox[{"yamplitude", "[", "i", "]"}], "*", "nxdata"}]}]}], 
          ";"}]}], "\n", "]"}], ";", "\n", 
       RowBox[{"Close", "[", "file", "]"}], ";"}]}], "\n", "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"nxfinal", "=", "nx"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"freq", "=", 
     RowBox[{"1", "/", 
      FractionBox[
       RowBox[{"h", " "}], 
       RowBox[{"kb", " ", "TCMB"}]]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"inten", "=", 
     RowBox[{
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]], "*", "2", " ", "h", " ", 
      RowBox[{
       SuperscriptBox["freq", "3"], "/", 
       SuperscriptBox["c", "2"]}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"z1", "=", 
     RowBox[{"ytoz", "[", 
      RowBox[{"yout", "[", "iminout", "]"}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"z2", "=", 
     RowBox[{"ytoz", "[", 
      RowBox[{"yout", "[", "imaxout", "]"}], "]"}]}], ";"}], "\n", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{
      RowBox[{"For", " ", "silk", " ", "damping", " ", "y"}], "-", 
      RowBox[{
      "distortion", " ", "is", " ", "only", " ", "an", " ", "order", " ", 
       "of", " ", "magnitude", " ", "estimate"}]}], ",", " ", 
     RowBox[{"cutoff", " ", "at", " ", "recombination"}]}], "*)"}], "\n", 
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"mode", "\[Equal]", "0"}], ",", 
      RowBox[{"zminint", "=", "1000.0"}], ",", 
      RowBox[{"zminint", "=", "zmin"}]}], "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"youtamp", "=", " ", 
     RowBox[{"0.25", "*", 
      RowBox[{"NIntegrate", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"dQdz", "[", "z", "]"}], "-", 
          RowBox[{"dQdzcooly", "[", "z", "]"}]}], ")"}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "zminint", ",", "z1"}], "}"}], ",", 
        RowBox[{"Method", "->", 
         RowBox[{"{", 
          RowBox[{"\"\<GlobalAdaptive\>\"", ",", 
           RowBox[{"Method", "->", 
            RowBox[{"{", "\"\<GaussKronrodRule\>\"", "}"}]}], ",", 
           RowBox[{"\"\<SingularityDepth\>\"", "->", "\[Infinity]"}]}], 
          "}"}]}], ",", 
        RowBox[{"PrecisionGoal", "->", "9"}], ",", 
        RowBox[{"MaxRecursion", "->", "20"}]}], "]"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"muoutamp", "=", " ", 
     RowBox[{"1.4", "*", 
      RowBox[{"NIntegrate", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Exp", "[", 
          RowBox[{"-", 
           RowBox[{"tau", "[", "z", "]"}]}], "]"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"dQdz", "[", "z", "]"}], "-", 
           RowBox[{"dQdzcool", "[", "z", "]"}]}], ")"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"z", ",", "z2", ",", "zmax"}], "}"}], ",", 
        RowBox[{"Method", "->", 
         RowBox[{"{", 
          RowBox[{"\"\<GlobalAdaptive\>\"", ",", 
           RowBox[{"Method", "->", 
            RowBox[{"{", "\"\<GaussKronrodRule\>\"", "}"}]}], ",", 
           RowBox[{"\"\<SingularityDepth\>\"", "->", "\[Infinity]"}]}], 
          "}"}]}], ",", 
        RowBox[{"PrecisionGoal", "->", "9"}], ",", 
        RowBox[{"MaxRecursion", "->", "20"}]}], "]"}]}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"youtdata", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"youtamp", "*", 
        RowBox[{"nszsol", "[", 
         RowBox[{"Exp", "[", "z", "]"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "zzmin", ",", "zzmax", ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"zzmax", "-", "zzmin"}], ")"}], "/", "1000.0"}]}], "}"}]}],
       "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"muoutdata", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"muoutamp", "*", 
        RowBox[{"musol", "[", 
         RowBox[{"Exp", "[", "z", "]"}], "]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"z", ",", "zzmin", ",", "zzmax", ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"zzmax", "-", "zzmin"}], ")"}], "/", "1000.0"}]}], "}"}]}],
       "]"}]}], ";"}], "\n", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"150", ":", 
      RowBox[{
       RowBox[{
       "975", " ", "elements", " ", "of", " ", "the", " ", "array", " ", 
        "select", " ", "approximately", " ", "x"}], ">", 
       SuperscriptBox["10", 
        RowBox[{"-", "4"}]]}]}], ",", " ", 
     RowBox[{"x", "<", 
      RowBox[{
      "80", " ", "to", " ", "avoid", " ", "boundaries", " ", "of", " ", "the",
        " ", "solution", " ", "in", " ", "the", " ", "templates"}]}]}], 
    "*)"}], "\n", 
   RowBox[{
    RowBox[{"nxoutdata", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Part", "[", 
         RowBox[{
          RowBox[{"Exp", "[", "xdata", "]"}], ",", 
          RowBox[{"150", ";;", "975"}]}], "]"}], ",", 
        RowBox[{"Part", "[", 
         RowBox[{"nx", ",", 
          RowBox[{"150", ";;", "975"}]}], "]"}], ",", 
        RowBox[{"Part", "[", 
         RowBox[{"youtdata", ",", 
          RowBox[{"150", ";;", "975"}]}], "]"}], ",", 
        RowBox[{"Part", "[", 
         RowBox[{"muoutdata", ",", 
          RowBox[{"150", ";;", "975"}]}], "]"}], ",", 
        RowBox[{"Part", "[", 
         RowBox[{
          RowBox[{"nx", "+", "youtdata", "+", "muoutdata"}], ",", 
          RowBox[{"150", ";;", "975"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Inuoutdata", "=", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Part", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"Exp", "[", "xdata", "]"}], "*", 
           RowBox[{"freq", "/", 
            SuperscriptBox["10", "9"]}]}], ",", 
          RowBox[{"150", ";;", "975"}]}], "]"}], ",", 
        RowBox[{"Part", "[", 
         RowBox[{
          RowBox[{"inten", "*", 
           SuperscriptBox[
            RowBox[{"Exp", "[", "xdata", "]"}], "3"], "*", "nx", "*", 
           RowBox[{"nbb", "[", 
            RowBox[{"Exp", "[", "xdata", "]"}], "]"}]}], ",", 
          RowBox[{"150", ";;", "975"}]}], "]"}], ",", 
        RowBox[{"Part", "[", 
         RowBox[{
          RowBox[{"inten", "*", 
           SuperscriptBox[
            RowBox[{"Exp", "[", "xdata", "]"}], "3"], "*", "youtdata", "*", 
           RowBox[{"nbb", "[", 
            RowBox[{"Exp", "[", "xdata", "]"}], "]"}]}], ",", 
          RowBox[{"150", ";;", "975"}]}], "]"}], ",", 
        RowBox[{"Part", "[", 
         RowBox[{
          RowBox[{"inten", "*", 
           SuperscriptBox[
            RowBox[{"Exp", "[", "xdata", "]"}], "3"], "*", "muoutdata", "*", 
           RowBox[{"nbb", "[", 
            RowBox[{"Exp", "[", "xdata", "]"}], "]"}]}], ",", 
          RowBox[{"150", ";;", "975"}]}], "]"}], ",", 
        RowBox[{"Part", "[", 
         RowBox[{
          RowBox[{"inten", "*", 
           SuperscriptBox[
            RowBox[{"Exp", "[", "xdata", "]"}], "3"], "*", 
           RowBox[{"(", 
            RowBox[{"nx", "+", "youtdata", "+", "muoutdata"}], ")"}], "*", 
           RowBox[{"nbb", "[", 
            RowBox[{"Exp", "[", "xdata", "]"}], "]"}]}], ",", 
          RowBox[{"150", ";;", "975"}]}], "]"}]}], "}"}], "]"}]}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"outfile1", ",", "nxoutdata"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"outfile2", ",", "Inuoutdata"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<\[Mu]-type distortion: \[Mu]=\>\"", ",", "muoutamp"}], 
     "]"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<y-type distortion: y=\>\"", ",", "youtamp"}], "]"}], ";"}], 
   "\n", 
   RowBox[{
    RowBox[{"youtdatafinal", "=", "youtdata"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"muoutdatafinal", "=", "muoutdata"}], ";"}]}]}]], "Code",
 InitializationCell->False,
 CellChangeTimes->{{3.5535867429385138`*^9, 3.553586787406464*^9}, {
   3.553843145929181*^9, 3.553843219052023*^9}, {3.553843516525483*^9, 
   3.553843518091614*^9}, {3.553843632520514*^9, 3.5538436339121113`*^9}, {
   3.5538441453468924`*^9, 3.553844152257143*^9}, {3.5538442463313913`*^9, 
   3.5538442483448763`*^9}, {3.553844323721342*^9, 3.553844326536141*^9}, {
   3.553844537945532*^9, 3.553844538059424*^9}, {3.553844663003014*^9, 
   3.553844663273467*^9}, {3.553848543816229*^9, 3.5538485443261223`*^9}, {
   3.553848594426964*^9, 3.553848595735202*^9}, {3.553848713211391*^9, 
   3.55384871356133*^9}, {3.553848755597247*^9, 3.5538487557572517`*^9}, {
   3.553848849155655*^9, 3.5538488494894533`*^9}, {3.553848891684383*^9, 
   3.553848891889673*^9}, {3.553849895119234*^9, 3.553849895517633*^9}, 
   3.553849980834592*^9, {3.553850071401425*^9, 3.55385007163861*^9}, {
   3.5538501961048517`*^9, 3.553850216269877*^9}, {3.553850288117701*^9, 
   3.553850343891502*^9}, {3.553850595108342*^9, 3.5538506012799053`*^9}, {
   3.553850663888019*^9, 3.553850664021285*^9}, {3.553850805736258*^9, 
   3.553850805926206*^9}, {3.553850939676837*^9, 3.553850945957844*^9}, {
   3.5538536875775747`*^9, 3.5538537893289013`*^9}, {3.553853926602174*^9, 
   3.553854012411762*^9}, {3.553855059459074*^9, 3.553855127583672*^9}, {
   3.553868679806553*^9, 3.553868941242758*^9}, {3.5538690001018133`*^9, 
   3.5538690042402687`*^9}, {3.553869052441675*^9, 3.553869055496667*^9}, {
   3.553869362461512*^9, 3.553869365450803*^9}, {3.55386948070979*^9, 
   3.553869492171822*^9}, {3.553925704032831*^9, 3.553925962834672*^9}, {
   3.553926302430191*^9, 3.5539263048960323`*^9}, {3.5545416675923843`*^9, 
   3.5545417052812*^9}, {3.5545417456515293`*^9, 3.554541765021818*^9}, {
   3.554543713738151*^9, 3.5545437144258747`*^9}, {3.554713669146294*^9, 
   3.554713669270988*^9}, 3.556349706085361*^9, {3.5563546312403717`*^9, 
   3.556354633252508*^9}, {3.556355020120008*^9, 3.556355032349635*^9}, {
   3.5846868654972057`*^9, 3.584686866300918*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"Solving ODE for Electron temperature\"\>"], "Print",
 CellChangeTimes->{3.554713669920641*^9, 3.556349749421731*^9, 
  3.556354740514709*^9, 3.556355034621379*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Total Files=\"\>", "\[InvisibleSpace]", "1901"}],
  SequenceForm["Total Files=", 1901],
  Editable->False]], "Print",
 CellChangeTimes->{3.554713669920641*^9, 3.556349749421731*^9, 
  3.556354740514709*^9, 3.5563550347308893`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ymin=\"\>", "\[InvisibleSpace]", "0.010000000000000002`"}],
  SequenceForm["ymin=", 0.010000000000000002`],
  Editable->False]], "Print",
 CellChangeTimes->{3.554713669920641*^9, 3.556349749421731*^9, 
  3.556354740514709*^9, 3.556355034829626*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"ymax=\"\>", "\[InvisibleSpace]", "2.0010000000000012`"}],
  SequenceForm["ymax=", 2.0010000000000012`],
  Editable->False]], "Print",
 CellChangeTimes->{3.554713669920641*^9, 3.556349749421731*^9, 
  3.556354740514709*^9, 3.556355034830735*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"\[Mu]-type distortion: \[Mu]=\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "1.6114006983338618`*^-9"}]}],
  SequenceForm["\[Mu]-type distortion: \[Mu]=", -1.6114006983338618`*^-9],
  Editable->False]], "Print",
 CellChangeTimes->{3.554713669920641*^9, 3.556349749421731*^9, 
  3.556354740514709*^9, 3.5563550399523573`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"y-type distortion: y=\"\>", "\[InvisibleSpace]", 
   RowBox[{"-", "4.69677730652879`*^-10"}]}],
  SequenceForm["y-type distortion: y=", -4.69677730652879*^-10],
  Editable->False]], "Print",
 CellChangeTimes->{3.554713669920641*^9, 3.556349749421731*^9, 
  3.556354740514709*^9, 3.556355040001018*^9}]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"checkAccuracy", "\[Equal]", "1"}], ",", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"nx", "=", "nxfinal"}], ";", "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{"Read", " ", "Rest", " ", "of", " ", "the", " ", "files"}], 
        " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", "1"}], ",", 
         RowBox[{"i", "\[LessEqual]", 
          RowBox[{"iminout", "-", "1"}]}], ",", 
         RowBox[{"i", "++"}], ",", "\n", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{"\"\<i=\>\"", ",", "i"}], "]"}], ";"}], "*)"}], "\n", 
         RowBox[{
          RowBox[{"y2", "=", 
           RowBox[{"yout", "[", "i", "]"}]}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"i", "\[Equal]", 
             RowBox[{"iminout", "-", "1"}]}], ",", 
            RowBox[{
             RowBox[{"yip1", "=", "y2"}], ";"}], ",", 
            RowBox[{
             RowBox[{"yip1", "=", 
              RowBox[{"yout", "[", 
               RowBox[{"i", "+", "1"}], "]"}]}], ";"}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"i", "\[Equal]", "1"}], ",", 
            RowBox[{
             RowBox[{"yim1", "=", "y2"}], ";"}], ",", 
            RowBox[{
             RowBox[{"yim1", "=", 
              RowBox[{"yout", "[", 
               RowBox[{"i", "-", "1"}], "]"}]}], ";"}]}], "]"}], ";", "\n", 
          RowBox[{"dy", "=", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"yip1", "-", "yim1"}], ")"}], "/", "2.0"}]}], ";", "\n", 
          
          RowBox[{"(*", 
           RowBox[{
            RowBox[{"Calculate", " ", "weights"}], " ", "=", 
            RowBox[{
             RowBox[{"energy", "/", "4"}], "*", 
             SuperscriptBox["10", "5"]}]}], "*)"}], "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"precision", "\[Equal]", "1"}], ",", "\n", 
            RowBox[{
             RowBox[{
              RowBox[{"yamplitude", "[", "i", "]"}], "=", 
              RowBox[{
               SuperscriptBox["10", "5"], "*", "0.25", "*", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"dQdz", "[", 
                   RowBox[{"ytoz", "[", "y2", "]"}], "]"}], "-", 
                  RowBox[{"dQdzcool", "[", 
                   RowBox[{"ytoz", "[", "y2", "]"}], "]"}]}], ")"}], "/", 
                RowBox[{"dydz", "[", 
                 RowBox[{"ytoz", "[", "y2", "]"}], "]"}]}], "*", "dy"}]}], 
             ";"}], ",", "\n", 
            RowBox[{
             RowBox[{
              RowBox[{"yamplitude", "[", "i", "]"}], "=", " ", 
              RowBox[{
               SuperscriptBox["10", "5"], "*", "0.25", "*", 
               RowBox[{"NIntegrate", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"dQdz", "[", "z", "]"}], "-", 
                   RowBox[{"dQdzcool", "[", "z", "]"}]}], ")"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"z", ",", 
                   RowBox[{"ytoz", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"y2", "+", "yim1"}], ")"}], "/", "2.0"}], "]"}], 
                   ",", 
                   RowBox[{"ytoz", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"yip1", "+", "y2"}], ")"}], "/", "2.0"}], "]"}]}],
                   "}"}], ",", 
                 RowBox[{"Method", "->", 
                  RowBox[{"{", 
                   RowBox[{"\"\<GlobalAdaptive\>\"", ",", 
                    RowBox[{"Method", "->", 
                    RowBox[{"{", "\"\<GaussKronrodRule\>\"", "}"}]}], ",", 
                    RowBox[{
                    "\"\<SingularityDepth\>\"", "->", "\[Infinity]"}]}], 
                   "}"}]}], ",", 
                 RowBox[{"PrecisionGoal", "->", "9"}], ",", 
                 RowBox[{"MaxRecursion", "->", "20"}]}], "]"}]}]}], ";"}]}], 
           "\n", "]"}], ";", "\n", 
          RowBox[{"file", "=", 
           RowBox[{"OpenRead", "[", 
            RowBox[{"root", "<>", "ystr", "<>", 
             RowBox[{"ToString", "[", "y2", "]"}], "<>", "\"\<.dat\>\""}], 
            "]"}]}], ";", "\n", 
          RowBox[{"data", "=", 
           RowBox[{"ReadList", "[", 
            RowBox[{"file", ",", 
             RowBox[{"{", 
              RowBox[{"Real", ",", "Real"}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"nxdata", "=", 
           RowBox[{"Part", "[", 
            RowBox[{
             RowBox[{"Transpose", "[", "data", "]"}], ",", "2"}], "]"}]}], 
          ";", "\n", 
          RowBox[{"nx", "=", 
           RowBox[{"nx", "+", 
            RowBox[{
             RowBox[{"yamplitude", "[", "i", "]"}], "*", "nxdata"}]}]}], ";", 
          "\n", 
          RowBox[{"Close", "[", "file", "]"}], ";"}]}], "\n", "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"For", "[", 
        RowBox[{
         RowBox[{"i", "=", 
          RowBox[{"imaxout", "+", "1"}]}], ",", 
         RowBox[{"i", "\[LessEqual]", "imax"}], ",", 
         RowBox[{"i", "++"}], ",", "\n", 
         RowBox[{"(*", 
          RowBox[{
           RowBox[{"Print", "[", 
            RowBox[{"\"\<i=\>\"", ",", "i"}], "]"}], ";"}], "*)"}], "\n", 
         RowBox[{
          RowBox[{"y2", "=", 
           RowBox[{"yout", "[", "i", "]"}]}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"i", "\[Equal]", "imax"}], ",", 
            RowBox[{
             RowBox[{"yip1", "=", "y2"}], ";"}], ",", 
            RowBox[{
             RowBox[{"yip1", "=", 
              RowBox[{"yout", "[", 
               RowBox[{"i", "+", "1"}], "]"}]}], ";"}]}], "]"}], ";", "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"i", "\[Equal]", 
             RowBox[{"imaxout", "+", "1"}]}], ",", 
            RowBox[{
             RowBox[{"yim1", "=", "y2"}], ";"}], ",", 
            RowBox[{
             RowBox[{"yim1", "=", 
              RowBox[{"yout", "[", 
               RowBox[{"i", "-", "1"}], "]"}]}], ";"}]}], "]"}], ";", "\n", 
          RowBox[{"dy", "=", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{"yip1", "-", "yim1"}], ")"}], "/", "2.0"}]}], ";", "\n", 
          
          RowBox[{"(*", 
           RowBox[{
            RowBox[{"Calculate", " ", "weights"}], " ", "=", 
            RowBox[{
             RowBox[{"energy", "/", "4"}], "*", 
             SuperscriptBox["10", "5"]}]}], "*)"}], "\n", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"precision", "\[Equal]", "1"}], ",", "\n", 
            RowBox[{
             RowBox[{
              RowBox[{"yamplitude", "[", "i", "]"}], "=", 
              RowBox[{
               SuperscriptBox["10", "5"], "*", "0.25", "*", 
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"dQdz", "[", 
                   RowBox[{"ytoz", "[", "y2", "]"}], "]"}], "-", 
                  RowBox[{"dQdzcool", "[", 
                   RowBox[{"ytoz", "[", "y2", "]"}], "]"}]}], ")"}], "/", 
                RowBox[{"dydz", "[", 
                 RowBox[{"ytoz", "[", "y2", "]"}], "]"}]}], "*", "dy"}]}], 
             ";"}], ",", "\n", 
            RowBox[{
             RowBox[{
              RowBox[{"yamplitude", "[", "i", "]"}], "=", " ", 
              RowBox[{
               SuperscriptBox["10", "5"], "*", "0.25", "*", 
               RowBox[{"NIntegrate", "[", 
                RowBox[{
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"dQdz", "[", "z", "]"}], "-", 
                   RowBox[{"dQdzcool", "[", "z", "]"}]}], ")"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"z", ",", 
                   RowBox[{"ytoz", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"y2", "+", "yim1"}], ")"}], "/", "2.0"}], "]"}], 
                   ",", 
                   RowBox[{"ytoz", "[", 
                    RowBox[{
                    RowBox[{"(", 
                    RowBox[{"yip1", "+", "y2"}], ")"}], "/", "2.0"}], "]"}]}],
                   "}"}], ",", 
                 RowBox[{"Method", "->", 
                  RowBox[{"{", 
                   RowBox[{"\"\<GlobalAdaptive\>\"", ",", 
                    RowBox[{"Method", "->", 
                    RowBox[{"{", "\"\<GaussKronrodRule\>\"", "}"}]}], ",", 
                    RowBox[{
                    "\"\<SingularityDepth\>\"", "->", "\[Infinity]"}]}], 
                   "}"}]}], ",", 
                 RowBox[{"PrecisionGoal", "->", "9"}], ",", 
                 RowBox[{"MaxRecursion", "->", "20"}]}], "]"}]}]}], ";"}]}], 
           "\n", "]"}], ";", "\n", 
          RowBox[{"file", "=", 
           RowBox[{"OpenRead", "[", 
            RowBox[{"root", "<>", "ystr", "<>", 
             RowBox[{"ToString", "[", "y2", "]"}], "<>", "\"\<.dat\>\""}], 
            "]"}]}], ";", "\n", 
          RowBox[{"data", "=", 
           RowBox[{"ReadList", "[", 
            RowBox[{"file", ",", 
             RowBox[{"{", 
              RowBox[{"Real", ",", "Real"}], "}"}]}], "]"}]}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"nxdata", "=", 
           RowBox[{"Part", "[", 
            RowBox[{
             RowBox[{"Transpose", "[", "data", "]"}], ",", "2"}], "]"}]}], 
          ";", "\n", 
          RowBox[{"nx", "=", 
           RowBox[{"nx", "+", 
            RowBox[{
             RowBox[{"yamplitude", "[", "i", "]"}], "*", "nxdata"}]}]}], ";", 
          "\n", 
          RowBox[{"Close", "[", "file", "]"}], ";"}]}], "\n", "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"nxfinalac", "=", "nx"}], ";", "\[IndentingNewLine]", 
       RowBox[{"z1ac", "=", 
        RowBox[{"ytoz", "[", 
         RowBox[{"yout", "[", "1", "]"}], "]"}]}], ";", "\n", 
       RowBox[{"z2ac", "=", 
        RowBox[{"ytoz", "[", 
         RowBox[{"yout", "[", "imax", "]"}], "]"}]}], ";", "\n", 
       RowBox[{"youtamp", "=", " ", 
        RowBox[{"0.25", "*", 
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"dQdz", "[", "z", "]"}], "-", 
             RowBox[{"dQdzcooly", "[", "z", "]"}]}], ")"}], ",", 
           RowBox[{"{", 
            RowBox[{"z", ",", "zminint", ",", "z1ac"}], "}"}], ",", 
           RowBox[{"Method", "->", 
            RowBox[{"{", 
             RowBox[{"\"\<GlobalAdaptive\>\"", ",", 
              RowBox[{"Method", "->", 
               RowBox[{"{", "\"\<GaussKronrodRule\>\"", "}"}]}], ",", 
              RowBox[{"\"\<SingularityDepth\>\"", "->", "\[Infinity]"}]}], 
             "}"}]}], ",", 
           RowBox[{"PrecisionGoal", "->", "9"}], ",", 
           RowBox[{"MaxRecursion", "->", "20"}]}], "]"}]}]}], ";", "\n", 
       RowBox[{"muoutamp", "=", " ", 
        RowBox[{"1.4", "*", 
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Exp", "[", 
             RowBox[{"-", 
              RowBox[{"tau", "[", "z", "]"}]}], "]"}], "*", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"dQdz", "[", "z", "]"}], "-", 
              RowBox[{"dQdzcool", "[", "z", "]"}]}], ")"}]}], ",", 
           RowBox[{"{", 
            RowBox[{"z", ",", "z2ac", ",", "zmax"}], "}"}], ",", 
           RowBox[{"Method", "->", 
            RowBox[{"{", 
             RowBox[{"\"\<GlobalAdaptive\>\"", ",", 
              RowBox[{"Method", "->", 
               RowBox[{"{", "\"\<GaussKronrodRule\>\"", "}"}]}], ",", 
              RowBox[{"\"\<SingularityDepth\>\"", "->", "\[Infinity]"}]}], 
             "}"}]}], ",", 
           RowBox[{"PrecisionGoal", "->", "9"}], ",", 
           RowBox[{"MaxRecursion", "->", "20"}]}], "]"}]}]}], ";", "\n", 
       RowBox[{"youtdata", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"youtamp", "*", 
           RowBox[{"nszsol", "[", 
            RowBox[{"Exp", "[", "z", "]"}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"z", ",", "zzmin", ",", "zzmax", ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"zzmax", "-", "zzmin"}], ")"}], "/", "1000.0"}]}], 
           "}"}]}], "]"}]}], ";", "\n", 
       RowBox[{"muoutdata", "=", 
        RowBox[{"Table", "[", 
         RowBox[{
          RowBox[{"muoutamp", "*", 
           RowBox[{"musol", "[", 
            RowBox[{"Exp", "[", "z", "]"}], "]"}]}], ",", 
          RowBox[{"{", 
           RowBox[{"z", ",", "zzmin", ",", "zzmax", ",", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{"zzmax", "-", "zzmin"}], ")"}], "/", "1000.0"}]}], 
           "}"}]}], "]"}]}], ";", "\n", 
       RowBox[{"(*", 
        RowBox[{
        "Discard", " ", "boundary", " ", "part", " ", "of", " ", "the", " ", 
         "spectrum"}], " ", "*)"}], "\[IndentingNewLine]", 
       RowBox[{"nxoutdata", "=", 
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Part", "[", 
            RowBox[{
             RowBox[{"Exp", "[", "xdata", "]"}], ",", 
             RowBox[{"150", ";;", "975"}]}], "]"}], ",", 
           RowBox[{"Part", "[", 
            RowBox[{"nx", ",", 
             RowBox[{"150", ";;", "975"}]}], "]"}], ",", 
           RowBox[{"Part", "[", 
            RowBox[{"youtdata", ",", 
             RowBox[{"150", ";;", "975"}]}], "]"}], ",", 
           RowBox[{"Part", "[", 
            RowBox[{"muoutdata", ",", 
             RowBox[{"150", ";;", "975"}]}], "]"}], ",", 
           RowBox[{"Part", "[", 
            RowBox[{
             RowBox[{"nx", "+", "youtdata", "+", "muoutdata"}], ",", 
             RowBox[{"150", ";;", "975"}]}], "]"}]}], "}"}], "]"}]}], ";", 
       "\n", 
       RowBox[{"Inuoutdata", "=", 
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"Part", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"Exp", "[", "xdata", "]"}], "*", 
              RowBox[{"freq", "/", 
               SuperscriptBox["10", "9"]}]}], ",", 
             RowBox[{"150", ";;", "975"}]}], "]"}], ",", 
           RowBox[{"Part", "[", 
            RowBox[{
             RowBox[{"inten", "*", 
              SuperscriptBox[
               RowBox[{"Exp", "[", "xdata", "]"}], "3"], "*", "nx", "*", 
              RowBox[{"nbb", "[", 
               RowBox[{"Exp", "[", "xdata", "]"}], "]"}]}], ",", 
             RowBox[{"150", ";;", "975"}]}], "]"}], ",", 
           RowBox[{"Part", "[", 
            RowBox[{
             RowBox[{"inten", "*", 
              SuperscriptBox[
               RowBox[{"Exp", "[", "xdata", "]"}], "3"], "*", "youtdata", "*", 
              RowBox[{"nbb", "[", 
               RowBox[{"Exp", "[", "xdata", "]"}], "]"}]}], ",", 
             RowBox[{"150", ";;", "975"}]}], "]"}], ",", 
           RowBox[{"Part", "[", 
            RowBox[{
             RowBox[{"inten", "*", 
              SuperscriptBox[
               RowBox[{"Exp", "[", "xdata", "]"}], "3"], "*", "muoutdata", 
              "*", 
              RowBox[{"nbb", "[", 
               RowBox[{"Exp", "[", "xdata", "]"}], "]"}]}], ",", 
             RowBox[{"150", ";;", "975"}]}], "]"}], ",", 
           RowBox[{"Part", "[", 
            RowBox[{
             RowBox[{"inten", "*", 
              SuperscriptBox[
               RowBox[{"Exp", "[", "xdata", "]"}], "3"], "*", 
              RowBox[{"(", 
               RowBox[{"nx", "+", "youtdata", "+", "muoutdata"}], ")"}], "*", 
              
              RowBox[{"nbb", "[", 
               RowBox[{"Exp", "[", "xdata", "]"}], "]"}]}], ",", 
             RowBox[{"150", ";;", "975"}]}], "]"}]}], "}"}], "]"}]}], ";", 
       "\n", 
       RowBox[{"outfile1ac", "=", 
        RowBox[{"\"\<ac_check\>\"", "<>", "outfile1"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"outfile2ac", "=", 
        RowBox[{"\"\<ac_check\>\"", "<>", "outfile2"}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{"Export", "[", 
        RowBox[{"outfile1ac", ",", "nxoutdata"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Export", "[", 
        RowBox[{"outfile2ac", ",", "Inuoutdata"}], "]"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<Accuracy Check: \[Mu]-type distortion: \[Mu]=\>\"", ",", 
         "muoutamp"}], "]"}], ";", "\n", 
       RowBox[{"Print", "[", 
        RowBox[{
        "\"\<Accuracy Check: y-type distortion: y=\>\"", ",", "youtamp"}], 
        "]"}], ";", "\[IndentingNewLine]", 
       RowBox[{"youtdatafinalac", "=", "youtdata"}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"muoutdatafinalac", "=", "muoutdata"}], ";", "\n", 
       RowBox[{"(*", "Checks", " ", "*)"}], "\[IndentingNewLine]", 
       "\[IndentingNewLine]", 
       RowBox[{"intensityint", "=", 
        RowBox[{"Interpolation", "[", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"xdata", ",", 
            RowBox[{"(", 
             RowBox[{"nxfinal", "+", "youtdatafinal", "+", "muoutdatafinal"}],
              ")"}]}], "}"}], "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"intensity", "[", "x_", "]"}], ":=", 
        RowBox[{"intensityint", "[", 
         RowBox[{"Log", "[", "x", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
       
       RowBox[{"Accurateintensityint", "=", 
        RowBox[{"Interpolation", "[", 
         RowBox[{"Transpose", "[", 
          RowBox[{"{", 
           RowBox[{"xdata", ",", 
            RowBox[{"(", 
             RowBox[{
             "nxfinalac", "+", "youtdatafinalac", "+", "muoutdatafinalac"}], 
             ")"}]}], "}"}], "]"}], "]"}]}], ";", "\n", 
       RowBox[{
        RowBox[{"Accurateintensity", "[", "x_", "]"}], "=", 
        RowBox[{"Accurateintensityint", "[", 
         RowBox[{"Log", "[", "x", "]"}], "]"}]}], ";", " ", 
       "\[IndentingNewLine]", 
       RowBox[{"(*", 
        RowBox[{
        "To", " ", "prevent", " ", "the", " ", "error", " ", "from", " ", 
         "blowing", " ", "up", " ", "when", " ", "denominator", " ", "goes", 
         " ", "to", " ", "zero"}], "*)"}], "\[IndentingNewLine]", 
       RowBox[{"Totaly", "=", 
        RowBox[{"0.125", "*", 
         RowBox[{"NIntegrate", "[", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"dQdz", "[", "z", "]"}], "-", 
             RowBox[{"dQdzcooly", "[", "z", "]"}]}], ")"}], ",", 
           RowBox[{"{", 
            RowBox[{"z", ",", "z1", ",", "z2"}], "}"}], ",", 
           RowBox[{"Method", "->", 
            RowBox[{"{", 
             RowBox[{"\"\<GlobalAdaptive\>\"", ",", 
              RowBox[{"Method", "->", 
               RowBox[{"{", "\"\<GaussKronrodRule\>\"", "}"}]}], ",", 
              RowBox[{"\"\<SingularityDepth\>\"", "->", "\[Infinity]"}]}], 
             "}"}]}], ",", 
           RowBox[{"PrecisionGoal", "->", "9"}], ",", 
           RowBox[{"MaxRecursion", "->", "20"}]}], "]"}]}]}], ";", 
       "\[IndentingNewLine]", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"intensityError", "[", "x_", "]"}], ":=", 
        FractionBox[
         RowBox[{"(", 
          RowBox[{
           RowBox[{"intensity", "[", "x", "]"}], "-", 
           RowBox[{"Accurateintensity", "[", "x", "]"}]}], ")"}], 
         RowBox[{"Max", "[", 
          RowBox[{
           RowBox[{"Abs", "[", 
            RowBox[{"Accurateintensity", "[", "x", "]"}], "]"}], ",", 
           RowBox[{"Abs", "[", "Totaly", "]"}], ",", 
           RowBox[{
            RowBox[{"Abs", "[", "youtamp", "]"}], "/", "2"}], ",", 
           RowBox[{
            RowBox[{"Abs", "[", "muoutamp", "]"}], "/", "10"}]}], "]"}]]}], 
       ";", "\[IndentingNewLine]", 
       RowBox[{"plot1", "=", 
        RowBox[{"LogLinearPlot", "[", 
         RowBox[{
          RowBox[{"intensityError", "[", "x", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0.2", ",", "10"}], "}"}], ",", 
          RowBox[{"AxesLabel", "\[Rule]", 
           RowBox[{"{", 
            RowBox[{"\"\<x\>\"", ",", "\"\<fractional Error\>\""}], "}"}]}], 
          ",", 
          RowBox[{
          "PlotLabel", "\[Rule]", 
           "\"\<Error due to assuming ymin,ymax=0.001,2\>\""}], ",", 
          RowBox[{"PlotRange", "\[Rule]", "All"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"Export", "[", 
        RowBox[{"error1file", ",", "plot1"}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]"}]}]], "Input",\

 CellChangeTimes->{
  3.5538403452613373`*^9, {3.55384048907059*^9, 3.553840540817852*^9}, {
   3.55384058425665*^9, 3.5538406749557257`*^9}, {3.5538407390770206`*^9, 
   3.5538409790364723`*^9}, {3.553841012092321*^9, 3.5538410799187403`*^9}, {
   3.553841125347823*^9, 3.55384124727072*^9}, {3.553841438059492*^9, 
   3.553841439655065*^9}, {3.553841641652907*^9, 3.553841646117955*^9}, 
   3.553841779127009*^9, {3.553841864352911*^9, 3.5538418793870287`*^9}, {
   3.5538420670159893`*^9, 3.553842126655637*^9}, 3.553842175091153*^9, {
   3.5538422324951887`*^9, 3.5538422372143507`*^9}, 3.553842280218285*^9, 
   3.5538427685578547`*^9, 3.553842822080985*^9, {3.553842890015643*^9, 
   3.553842907036622*^9}, {3.553853484556653*^9, 3.5538536431108217`*^9}, {
   3.553854731808215*^9, 3.553854737772985*^9}, {3.5563498744257803`*^9, 
   3.5563498830144978`*^9}, {3.556349916837947*^9, 3.556349944119445*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
   "Check", " ", "with", " ", "numerical", " ", "solutions", " ", "given", 
    " ", "in", " ", "examples"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
    "spectrumfile", "=", "\"\<examples/Particle_decay_z7.0e4.dat\>\""}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"spectrumdata", "=", 
     RowBox[{"Interpolation", "[", 
      RowBox[{"ReadList", "[", 
       RowBox[{"spectrumfile", ",", 
        RowBox[{"{", 
         RowBox[{"Real", ",", "Real"}], "}"}]}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"ispectrum", "[", "x_", "]"}], "=", 
     RowBox[{"spectrumdata", "[", 
      RowBox[{"Log", "[", "x", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"internxint", "=", 
     RowBox[{"Interpolation", "[", 
      RowBox[{"Transpose", "[", 
       RowBox[{"{", 
        RowBox[{"xdata", ",", "nxfinal"}], "}"}], "]"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"internx", "[", "x_", "]"}], ":=", 
     RowBox[{"internxint", "[", 
      RowBox[{"Log", "[", "x", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"internxError", "[", "x_", "]"}], ":=", 
     FractionBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"internx", "[", "x", "]"}], "-", 
        RowBox[{"ispectrum", "[", "x", "]"}]}], ")"}], 
      RowBox[{"Max", "[", 
       RowBox[{
        RowBox[{"Abs", "[", 
         RowBox[{"ispectrum", "[", "x", "]"}], "]"}], ",", 
        RowBox[{"Abs", "[", "Totaly", "]"}], ",", 
        RowBox[{
         RowBox[{"Abs", "[", "youtamp", "]"}], "/", "2"}], ",", 
        RowBox[{
         RowBox[{"Abs", "[", "muoutamp", "]"}], "/", "10"}]}], "]"}]]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"plot2", "=", 
     RowBox[{"LogLinearPlot", "[", 
      RowBox[{
       RowBox[{"internxError", "[", "x", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "0.1", ",", "10"}], "}"}], ",", 
       RowBox[{"AxesLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{"\"\<x\>\"", ",", "\"\<fractional Error\>\""}], "}"}]}], ",", 
       RowBox[{
       "PlotLabel", "\[Rule]", 
        "\"\<Error with respect to numerical solution\>\""}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"error2file", ",", "plot2"}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{
  3.5538403452613373`*^9, {3.55384048907059*^9, 3.553840540817852*^9}, {
   3.55384058425665*^9, 3.5538406749557257`*^9}, {3.5538407390770206`*^9, 
   3.5538409790364723`*^9}, {3.553841012092321*^9, 3.5538410799187403`*^9}, {
   3.553841125347823*^9, 3.55384124727072*^9}, {3.553841438059492*^9, 
   3.553841439655065*^9}, {3.553841641652907*^9, 3.553841646117955*^9}, 
   3.553841779127009*^9, {3.553841864352911*^9, 3.5538418793870287`*^9}, {
   3.553841919597082*^9, 3.553842050927676*^9}, {3.553842179858295*^9, 
   3.553842214180613*^9}, {3.553842325868547*^9, 3.553842394907558*^9}, {
   3.553842671392619*^9, 3.553842710482255*^9}, {3.553842935830373*^9, 
   3.5538429438125343`*^9}, {3.553843591600745*^9, 3.5538435936004963`*^9}, {
   3.5538437510116987`*^9, 3.55384379742918*^9}, {3.553843956297221*^9, 
   3.553843979306445*^9}, {3.55384401724404*^9, 3.553844019785281*^9}, {
   3.5538442091559277`*^9, 3.5538442126430273`*^9}, {3.553844302592512*^9, 
   3.553844304559702*^9}, {3.553844358151067*^9, 3.5538443606937323`*^9}, {
   3.553844706647203*^9, 3.5538447069187393`*^9}, {3.553850101555809*^9, 
   3.553850101874961*^9}, {3.553850133539668*^9, 3.553850138179494*^9}, {
   3.553850768911326*^9, 3.553850788878932*^9}, {3.55385089241716*^9, 
   3.553850892688714*^9}, {3.5538510044003363`*^9, 3.553851015187236*^9}, {
   3.55385122537495*^9, 3.5538512320770693`*^9}, {3.553851280984891*^9, 
   3.5538513051588984`*^9}, {3.553853901653954*^9, 3.553853904693532*^9}, {
   3.553854797876687*^9, 3.553854818374839*^9}, {3.553854956841256*^9, 
   3.553854981849793*^9}, {3.553858941820079*^9, 3.5538589480196037`*^9}}]
},
WindowSize->{1918, 1168},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> True}},
ShowSelection->True,
FrontEndVersion->"9.0 for Linux x86 (64-bit) (January 25, 2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 68049, 1894, 6474, "Code",
 InitializationCell->False],
Cell[CellGroupData[{
Cell[68653, 1920, 181, 2, 23, "Print"],
Cell[68837, 1924, 279, 6, 23, "Print"],
Cell[69119, 1932, 297, 6, 23, "Print"],
Cell[69419, 1940, 293, 6, 23, "Print"],
Cell[69715, 1948, 371, 7, 25, "Print"],
Cell[70089, 1957, 350, 7, 25, "Print"]
}, Open  ]]
}, Open  ]],
Cell[70466, 1968, 21840, 521, 1499, "Input"],
Cell[92309, 2491, 4216, 95, 269, "Input"]
}
]
*)

(* End of internal cache information *)
